<?php
// Iniciar buffer de salida al principio del archivo
ob_start();

// Configuración de errores para desarrollo (quitar en producción)
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Iniciar sesión segura
if (session_status() !== PHP_SESSION_ACTIVE) {
    session_start();
}

// Verificar autenticación
if (!isset($_SESSION['admin_id'])) {
    ob_end_clean(); // Limpiar buffer antes de redireccionar
    header("Location: login.php");
    exit;
}

// Conexión a base de datos
require_once '../config/database.php';

// Inicializar variables
$error = '';
$success = '';
$form_data = [
    'nombre' => '',
    'descripcion' => '',
    'fecha_inicio' => '',
    'fecha_fin' => '',
    'cupo_maximo' => '',
    'numero_registro' => '',
    'es_exclusivo' => false,
    'codigo_acceso' => ''
];

// Procesar formulario
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    // Recoger y sanitizar datos
    $form_data['nombre'] = trim($_POST['nombre']);
    $form_data['descripcion'] = trim($_POST['descripcion']);
    $form_data['fecha_inicio'] = $_POST['fecha_inicio'];
    $form_data['fecha_fin'] = $_POST['fecha_fin'];
    $form_data['cupo_maximo'] = (int)$_POST['cupo_maximo'];
    $form_data['numero_registro'] = trim($_POST['numero_registro']);
    $form_data['es_exclusivo'] = isset($_POST['es_exclusivo']) ? 1 : 0;
    $form_data['codigo_acceso'] = trim($_POST['codigo_acceso'] ?? '');

    // Validar que si es exclusivo, tenga código de acceso
    if ($form_data['es_exclusivo'] && empty($form_data['codigo_acceso'])) {
        $error = "Los cursos exclusivos deben tener un código de acceso";
    } else {
        // Validar fechas
        if (strtotime($form_data['fecha_inicio']) > strtotime($form_data['fecha_fin'])) {
            $error = "La fecha de fin no puede ser anterior a la fecha de inicio";
        } else {
            try {
                // Verificar si el número de registro ya existe
                $stmt = $pdo->prepare("SELECT COUNT(*) FROM cursos WHERE numero_registro = ?");
                $stmt->execute([$form_data['numero_registro']]);
                $registro_existente = $stmt->fetchColumn();

                if ($registro_existente > 0) {
                    $error = "El número de registro ya está en uso. Por favor, elige otro.";
                } else {
                    // Iniciar transacción
                    $pdo->beginTransaction();

                    // Insertar el curso en la base de datos
                    $stmt = $pdo->prepare("INSERT INTO cursos (nombre, descripcion, fecha_inicio, fecha_fin, cupo_maximo, numero_registro, estado, habilitado, es_exclusivo, codigo_acceso) 
                                           VALUES (?, ?, ?, ?, ?, ?, 'activo', 1, ?, ?)");
                    $stmt->execute([
                        $form_data['nombre'],
                        $form_data['descripcion'],
                        $form_data['fecha_inicio'],
                        $form_data['fecha_fin'],
                        $form_data['cupo_maximo'],
                        $form_data['numero_registro'],
                        $form_data['es_exclusivo'],
                        $form_data['codigo_acceso']
                    ]);

                    // Crear carpeta para el curso
                    $carpetaBase = '../cursos/';
                    if (!file_exists($carpetaBase)) {
                        if (!mkdir($carpetaBase, 0777, true)) {
                            throw new Exception("No se pudo crear el directorio base de cursos");
                        }
                    }

                    // Generar nombre de carpeta seguro
                    $nombreCarpeta = preg_replace('/[^A-Za-z0-9\-]/', '', str_replace(' ', '_', $form_data['nombre'])) . '_' . $form_data['numero_registro'];
                    $rutaCarpetaCurso = $carpetaBase . $nombreCarpeta;

                    if (!file_exists($rutaCarpetaCurso)) {
                        if (!mkdir($rutaCarpetaCurso, 0777, true)) {
                            throw new Exception("Error al crear la carpeta del curso. Verifique los permisos.");
                        }
                    }

                    // Confirmar transacción
                    $pdo->commit();

                    // Limpiar buffer y redireccionar
                    ob_end_clean();
                    $_SESSION['flash_message'] = [
                        'type' => 'success',
                        'message' => 'Curso creado exitosamente'
                    ];
                    header("Location: ver_cursos.php");
                    exit;
                }
            } catch (PDOException $e) {
                $pdo->rollBack();
                $error = "Error de base de datos: " . $e->getMessage();
            } catch (Exception $e) {
                if (isset($pdo) && $pdo->inTransaction()) {
                    $pdo->rollBack();
                }
                $error = $e->getMessage();
            }
        }
    }
}

// Mostrar formulario
ob_end_flush();
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Crear Curso | ESIBOC</title>
    
    <!-- Google Font: Source Sans Pro -->
    <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,400i,700&display=fallback">
    <!-- Font Awesome -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Theme style -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/css/adminlte.min.css">
    <!-- Bootstrap Datepicker -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-datepicker/1.9.0/css/bootstrap-datepicker.min.css">
    <!-- Custom CSS -->
    <style>
        .card-primary.card-outline {
            border-top: 3px solid #007bff;
        }
        .section-title {
            font-size: 1.1rem;
            color: #007bff;
            border-bottom: 1px solid #dee2e6;
            padding-bottom: 0.5rem;
            margin-bottom: 1.5rem;
        }
        .file-info {
            font-size: 0.8rem;
            color: #6c757d;
            margin-top: 0.25rem;
        }
        /* Estilos para el menú fijo y scroll */
        .main-sidebar {
            position: fixed;
            height: 100vh;
            overflow-y: auto;
        }
        .content-wrapper {
            margin-left: 250px;
            overflow-y: auto;
            height: 100vh;
        }
        .main-header {
            position: fixed;
            width: 100%;
            z-index: 1030;
            left: 0;
        }
        .content {
            padding-top: 70px;
            padding-bottom: 60px;
        }
        .main-footer {
            position: fixed;
            bottom: 0;
            width: 100%;
            margin-left: 250px;
            z-index: 1000;
            background: #fff;
        }
        .pagination-container {
            display: flex;
            justify-content: center;
            margin-top: 20px;
        }
        .required-field::after {
            content: " *";
            color: red;
        }
        .custom-switch .custom-control-label::before {
            width: 2.5rem;
            height: 1.25rem;
        }
        .custom-switch .custom-control-label::after {
            width: calc(1.25rem - 4px);
            height: calc(1.25rem - 4px);
        }
    </style>
</head>
<body class="hold-transition sidebar-mini">
<div class="wrapper">

    <!-- Navbar -->
    <nav class="main-header navbar navbar-expand navbar-white navbar-light">
        <!-- Left navbar links -->
        <ul class="navbar-nav">
            <li class="nav-item">
                <a class="nav-link" data-widget="pushmenu" href="#" role="button"><i class="fas fa-bars"></i></a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="dashboard.php" class="nav-link">Inicio</a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="ver_cursos.php" class="nav-link">Cursos</a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="#" class="nav-link active">Crear Curso</a>
            </li>
        </ul>
    </nav>
    <!-- /.navbar -->

    <!-- Main Sidebar Container -->
    <aside class="main-sidebar sidebar-dark-primary elevation-4">
        <!-- Brand Logo -->
        <a href="dashboard.php" class="brand-link">
            <span class="brand-text font-weight-light">ESIBOC Admin</span>
        </a>

        <!-- Sidebar -->
        <div class="sidebar">
            <!-- Sidebar user panel (optional) -->
            <div class="user-panel mt-3 pb-3 mb-3 d-flex">
                <div class="image">
                    <span class="img-circle elevation-2 bg-info d-flex align-items-center justify-content-center" 
                          style="width: 40px; height: 40px; font-weight: bold; font-size: 18px;">
                        <?= strtoupper(substr($_SESSION['admin_nombre'], 0, 1)) ?>
                    </span>
                </div>
                <div class="info">
                    <a href="#" class="d-block"><?= htmlspecialchars($_SESSION['admin_nombre']) ?></a>
                </div>
            </div>

            <!-- Sidebar Menu -->
            <nav class="mt-2">
                <ul class="nav nav-pills nav-sidebar flex-column" data-widget="treeview" role="menu" data-accordion="false">
                    <li class="nav-item">
                        <a href="dashboard.php" class="nav-link">
                            <i class="nav-icon fas fa-tachometer-alt"></i>
                            <p>Dashboard</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="crear_curso.php" class="nav-link active">
                            <i class="nav-icon fas fa-plus-circle"></i>
                            <p>Crear Curso</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="ver_cursos.php" class="nav-link">
                            <i class="nav-icon fas fa-book"></i>
                            <p>Gestionar Cursos</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="inscribir_participante.php" class="nav-link">
                            <i class="nav-icon fas fa-user-plus"></i>
                            <p>Inscribir Participante</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="ver_inscritos.php" class="nav-link">
                            <i class="nav-icon fas fa-clipboard-list"></i>
                            <p>Ver Inscripciones</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="logout.php" class="nav-link text-danger">
                            <i class="nav-icon fas fa-sign-out-alt"></i>
                            <p>Cerrar Sesión</p>
                        </a>
                    </li>
                </ul>
            </nav>
            <!-- /.sidebar-menu -->
        </div>
        <!-- /.sidebar -->
    </aside>

    <!-- Content Wrapper. Contains page content -->
    <div class="content-wrapper">
        <!-- Content Header (Page header) -->
        <section class="content-header">
            <div class="container-fluid">
                <div class="row mb-2">
                    <div class="col-sm-6">
                        <h1>Crear Nuevo Curso</h1>
                    </div>
                    <div class="col-sm-6">
                        <ol class="breadcrumb float-sm-right">
                            <li class="breadcrumb-item"><a href="dashboard.php">Inicio</a></li>
                            <li class="breadcrumb-item"><a href="ver_cursos.php">Cursos</a></li>
                            <li class="breadcrumb-item active">Crear Curso</li>
                        </ol>
                    </div>
                </div>
            </div><!-- /.container-fluid -->
        </section>

        <!-- Main content -->
        <section class="content">
            <div class="container-fluid">
                <div class="row">
                    <div class="col-md-12">
                        <!-- general form elements -->
                        <div class="card card-primary card-outline">
                            <div class="card-header">
                                <h3 class="card-title">Complete los datos del curso</h3>
                            </div>
                            <!-- /.card-header -->
                            
                            <?php if ($error): ?>
                                <div class="alert alert-danger alert-dismissible ml-3 mr-3 mt-3">
                                    <button type="button" class="close" data-dismiss="alert" aria-hidden="true">×</button>
                                    <h5><i class="icon fas fa-ban"></i> Error!</h5>
                                    <?= htmlspecialchars($error) ?>
                                </div>
                            <?php endif; ?>

                            <!-- form start -->
                            <form action="crear_curso.php" method="POST" id="cursoForm">
                                <div class="card-body">
                                    <!-- Sección Información Básica -->
                                    <h4 class="section-title"><i class="fas fa-info-circle mr-2"></i>Información Básica</h4>
                                    <div class="row">
                                        <div class="col-md-6">
                                            <div class="form-group">
                                                <label for="nombre" class="required-field">Nombre del curso</label>
                                                <input type="text" class="form-control" id="nombre" name="nombre" 
                                                       value="<?= htmlspecialchars($form_data['nombre']) ?>" 
                                                       placeholder="Ej: Primeros Auxilios Avanzados" required>
                                            </div>
                                        </div>
                                        <div class="col-md-6">
                                            <div class="form-group">
                                                <label for="numero_registro" class="required-field">Número de registro</label>
                                                <input type="text" class="form-control" id="numero_registro" name="numero_registro" 
                                                       value="<?= htmlspecialchars($form_data['numero_registro']) ?>" 
                                                       placeholder="Ej: CUR-2023-001" required>
                                                <span class="file-info">Este número debe ser único para cada curso</span>
                                            </div>
                                        </div>
                                    </div>
                                    <div class="form-group">
                                        <label for="descripcion" class="required-field">Descripción del curso</label>
                                        <textarea class="form-control" id="descripcion" name="descripcion" 
                                                  rows="4" placeholder="Descripción detallada del curso..." required><?= htmlspecialchars($form_data['descripcion']) ?></textarea>
                                    </div>

                                    <!-- Sección Fechas y Cupos -->
                                    <h4 class="section-title mt-4"><i class="fas fa-calendar-alt mr-2"></i>Fechas y Cupos</h4>
                                    <div class="row">
                                        <div class="col-md-4">
                                            <div class="form-group">
                                                <label for="fecha_inicio" class="required-field">Fecha de inicio</label>
                                                <input type="date" class="form-control" id="fecha_inicio" name="fecha_inicio" 
                                                       value="<?= htmlspecialchars($form_data['fecha_inicio']) ?>" required>
                                            </div>
                                        </div>
                                        <div class="col-md-4">
                                            <div class="form-group">
                                                <label for="fecha_fin" class="required-field">Fecha de fin</label>
                                                <input type="date" class="form-control" id="fecha_fin" name="fecha_fin" 
                                                       value="<?= htmlspecialchars($form_data['fecha_fin']) ?>" required>
                                            </div>
                                        </div>
                                        <div class="col-md-4">
                                            <div class="form-group">
                                                <label for="cupo_maximo" class="required-field">Cupo máximo</label>
                                                <input type="number" class="form-control" id="cupo_maximo" name="cupo_maximo" 
                                                       value="<?= htmlspecialchars($form_data['cupo_maximo']) ?>"
                                                       min="1" max="100" required>
                                                <span class="file-info">Máximo 100 participantes</span>
                                            </div>
                                        </div>
                                    </div>

                                    <!-- Sección Configuración de Acceso -->
                                    <h4 class="section-title mt-4"><i class="fas fa-lock mr-2"></i>Configuración de Acceso</h4>
                                    <div class="row">
                                        <div class="col-md-6">
                                            <div class="form-group">
                                                <div class="custom-control custom-switch">
                                                    <input type="checkbox" class="custom-control-input" id="es_exclusivo" name="es_exclusivo" 
                                                           <?= $form_data['es_exclusivo'] ? 'checked' : '' ?>>
                                                    <label class="custom-control-label" for="es_exclusivo">Curso exclusivo (requiere código de acceso)</label>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-md-6" id="codigo_acceso_container" style="<?= $form_data['es_exclusivo'] ? '' : 'display: none;' ?>">
                                            <div class="form-group">
                                                <label for="codigo_acceso">Código de acceso</label>
                                                <input type="text" class="form-control" id="codigo_acceso" name="codigo_acceso" 
                                                       value="<?= htmlspecialchars($form_data['codigo_acceso']) ?>" 
                                                       placeholder="Ej: BOMBEROS2023">
                                                <span class="file-info">Este código será requerido para inscribirse</span>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <!-- /.card-body -->

                                <div class="card-footer">
                                    <button type="submit" class="btn btn-primary">
                                        <i class="fas fa-plus-circle mr-2"></i>Crear Curso
                                    </button>
                                    <a href="ver_cursos.php" class="btn btn-default float-right">
                                        <i class="fas fa-times mr-2"></i>Cancelar
                                    </a>
                                </div>
                            </form>
                        </div>
                        <!-- /.card -->
                    </div>
                </div>
                <!-- /.row -->
            </div><!-- /.container-fluid -->
        </section>
        <!-- /.content -->
    </div>
    <!-- /.content-wrapper -->

    <!-- Main Footer -->
    <footer class="main-footer">
        <strong>Copyright &copy; <?= date('Y') ?> <a href="#">ESIBOC</a>.</strong>
        Todos los derechos reservados.
        <div class="float-right d-none d-sm-inline-block">
            <b>Versión</b> 1.0.0
        </div>
    </footer>
</div>
<!-- ./wrapper -->

<!-- REQUIRED SCRIPTS -->
<!-- jQuery -->
<script src="https://cdn.jsdelivr.net/npm/jquery@3.6.0/dist/jquery.min.js"></script>
<!-- Bootstrap 4 -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/js/bootstrap.bundle.min.js"></script>
<!-- AdminLTE App -->
<script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>
<!-- Bootstrap Datepicker -->
<script src="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-datepicker/1.9.0/js/bootstrap-datepicker.min.js"></script>
<script>
$(function () {
    // Inicializar datepicker
    $('#fecha_inicio, #fecha_fin').datepicker({
        format: 'yyyy-mm-dd',
        autoclose: true,
        todayHighlight: true
    });

    // Validación de fechas
    $('#cursoForm').submit(function() {
        const fechaInicio = new Date($('#fecha_inicio').val());
        const fechaFin = new Date($('#fecha_fin').val());
        
        if (fechaInicio > fechaFin) {
            alert('La fecha de fin no puede ser anterior a la fecha de inicio');
            return false;
        }
        
        // Validar cupo máximo
        const cupoMaximo = parseInt($('#cupo_maximo').val());
        if (cupoMaximo < 1 || cupoMaximo > 100) {
            alert('El cupo máximo debe estar entre 1 y 100');
            return false;
        }

        // Validar que si es exclusivo, tenga código de acceso
        if ($('#es_exclusivo').is(':checked') && $('#codigo_acceso').val().trim() === '') {
            alert('Los cursos exclusivos deben tener un código de acceso');
            return false;
        }
        
        return true;
    });

    // Mostrar/ocultar campo de código de acceso
    $('#es_exclusivo').change(function() {
        if ($(this).is(':checked')) {
            $('#codigo_acceso_container').show();
            $('#codigo_acceso').prop('required', true);
        } else {
            $('#codigo_acceso_container').hide();
            $('#codigo_acceso').prop('required', false);
        }
    });
});
</script>
</body>
</html>