<?php
// 1. Configuración inicial estricta
session_start();
ob_start(); // Iniciar buffer de salida inmediatamente

// 2. Incluir archivos necesarios
require_once __DIR__ . '/../config/database.php';

// 3. Verificación de seguridad mejorada
if (!isset($_SESSION['admin_id'])) {
    header("Location: /admin/login.php");
    exit;
}

// 4. Validación robusta de entrada
$curso_id = filter_input(INPUT_GET, 'curso_id', FILTER_VALIDATE_INT);
if (!$curso_id || $curso_id < 1) {
    die("ID de curso inválido");
}

// 5. Obtener información del curso con manejo de errores
try {
    $stmt = $pdo->prepare("SELECT nombre, numero_registro FROM cursos WHERE id = ?");
    if (!$stmt->execute([$curso_id])) {
        throw new Exception("Error al consultar la base de datos");
    }
    
    $curso = $stmt->fetch();
    if (!$curso) {
        throw new Exception("Curso no encontrado");
    }
    
    // 6. Sanitización de nombres de archivos
    $nombreLimpio = preg_replace('/[^A-Za-z0-9\-_]/', '', $curso['nombre']);
    $nombreCarpeta = $nombreLimpio . '_' . $curso['numero_registro'];
    $zipFileName = $nombreCarpeta . '.zip';
    
    // 7. Configuración de rutas seguras
    $rutaBase = realpath(__DIR__ . '/../cursos');
    if ($rutaBase === false) {
        throw new Exception("No se pudo encontrar la ruta base de cursos");
    }
    
    $rutaCarpetaCurso = $rutaBase . DIRECTORY_SEPARATOR . $nombreCarpeta;
    
    // 8. Verificación de seguridad de rutas
    if (strpos(realpath($rutaCarpetaCurso), realpath($rutaBase)) !== 0) {
        throw new Exception("Intento de acceso a ruta no permitida");
    }
    
    if (!is_dir($rutaCarpetaCurso)) {
        throw new Exception("La carpeta del curso no existe: " . $nombreCarpeta);
    }
    
    // 9. Configuración de límites para archivos grandes
    ini_set('memory_limit', '512M');
    ini_set('max_execution_time', 300);
    set_time_limit(300);
    
    // 10. Crear archivo ZIP temporal con nombre único
    $tempZip = tempnam(sys_get_temp_dir(), 'zip_');
    if ($tempZip === false) {
        throw new Exception("No se pudo crear archivo temporal");
    }
    
    // 11. Método preferido: ZipArchive
    if (class_exists('ZipArchive')) {
        $zip = new ZipArchive();
        if ($zip->open($tempZip, ZipArchive::CREATE | ZipArchive::OVERWRITE) !== true) {
            throw new Exception("No se pudo abrir el archivo ZIP para escritura");
        }
        
        $files = new RecursiveIteratorIterator(
            new RecursiveDirectoryIterator($rutaCarpetaCurso, RecursiveDirectoryIterator::SKIP_DOTS),
            RecursiveIteratorIterator::SELF_FIRST
        );
        
        foreach ($files as $file) {
            $filePath = $file->getRealPath();
            $relativePath = substr($filePath, strlen($rutaCarpetaCurso) + 1);
            
            if ($file->isDir()) {
                $zip->addEmptyDir($relativePath);
            } elseif ($file->isFile()) {
                $zip->addFile($filePath, $relativePath);
            }
        }
        
        if (!$zip->close()) {
            throw new Exception("Error al finalizar el archivo ZIP");
        }
    }
    // 12. Método alternativo para hosting sin ZipArchive
    else {
        $old_cwd = getcwd();
        chdir($rutaBase);
        
        $command = "zip -r " . escapeshellarg($tempZip) . " " . escapeshellarg($nombreCarpeta) . " 2>&1";
        exec($command, $output, $returnVar);
        
        chdir($old_cwd);
        
        if ($returnVar !== 0 || !file_exists($tempZip)) {
            throw new Exception("Error al comprimir: " . implode("\n", $output));
        }
    }
    
    // 13. Verificación final del archivo ZIP
    if (!file_exists($tempZip) || filesize($tempZip) === 0) {
        throw new Exception("El archivo ZIP generado está vacío");
    }
    
    // 14. Limpiar todos los buffers de salida
    while (ob_get_level()) {
        ob_end_clean();
    }
    
    // 15. Configurar headers para descarga
    header('Content-Description: File Transfer');
    header('Content-Type: application/zip');
    header('Content-Disposition: attachment; filename="' . $zipFileName . '"');
    header('Content-Length: ' . filesize($tempZip));
    header('Expires: 0');
    header('Cache-Control: must-revalidate, post-check=0, pre-check=0');
    header('Pragma: public');
    
    // 16. Enviar el archivo
    if (readfile($tempZip) === false) {
        throw new Exception("Error al enviar el archivo al navegador");
    }
    
    // 17. Eliminar archivo temporal
    @unlink($tempZip);
    exit;
    
} catch (Exception $e) {
    // 18. Manejo de errores centralizado
    while (ob_get_level()) {
        ob_end_clean();
    }
    
    http_response_code(500);
    die("Error: " . $e->getMessage());
}