<?php
// Iniciar buffer y sesión al principio absoluto
ob_start();
session_start();

// Configuración de errores (solo para desarrollo)
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Verificación de sesión
if (!isset($_SESSION['admin_id'])) {
    header("Location: login.php");
    ob_end_flush();
    exit();
}

// Conexión a la base de datos
require_once __DIR__.'/../config/database.php';

// Validación del ID del curso
if (!isset($_GET['id']) || !ctype_digit($_GET['id'])) {
    $_SESSION['error'] = "ID de curso no válido";
    header("Location: ver_cursos.php");
    ob_end_flush();
    exit();
}

$curso_id = (int)$_GET['id'];

// Obtener datos del curso
try {
    $stmt = $pdo->prepare("SELECT * FROM cursos WHERE id = ?");
    $stmt->execute([$curso_id]);
    $curso = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$curso) {
        $_SESSION['error'] = "No se encontró el curso solicitado";
        header("Location: ver_cursos.php");
        ob_end_flush();
        exit();
    }
} catch (PDOException $e) {
    error_log("Error al obtener curso: " . $e->getMessage());
    $_SESSION['error'] = "Error al cargar los datos del curso";
    header("Location: ver_cursos.php");
    ob_end_flush();
    exit();
}

// Procesamiento del formulario
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // Recoger y validar datos
        $datos = [
            'nombre' => trim($_POST['nombre'] ?? ''),
            'descripcion' => trim($_POST['descripcion'] ?? ''),
            'fecha_inicio' => $_POST['fecha_inicio'] ?? '',
            'fecha_fin' => $_POST['fecha_fin'] ?? '',
            'cupo_maximo' => isset($_POST['cupo_maximo']) ? (int)$_POST['cupo_maximo'] : 0,
            'numero_registro' => trim($_POST['numero_registro'] ?? ''),
            'es_exclusivo' => isset($_POST['es_exclusivo']) ? 1 : 0,
            'codigo_acceso' => trim($_POST['codigo_acceso'] ?? '')
        ];

        // Validaciones
        $errores = [];
        
        if (empty($datos['nombre'])) $errores[] = "El nombre del curso es obligatorio";
        if (empty($datos['descripcion'])) $errores[] = "La descripción es obligatoria";
        if (empty($datos['fecha_inicio'])) $errores[] = "La fecha de inicio es obligatoria";
        if (empty($datos['fecha_fin'])) $errores[] = "La fecha de fin es obligatoria";
        if ($datos['cupo_maximo'] <= 0 || $datos['cupo_maximo'] > 100) $errores[] = "El cupo debe ser entre 1 y 100";
        if (empty($datos['numero_registro'])) $errores[] = "El número de registro es obligatorio";
        
        if ($datos['fecha_inicio'] > $datos['fecha_fin']) {
            $errores[] = "La fecha de inicio no puede ser posterior a la fecha de fin";
        }

        // Validar que si es exclusivo, tenga código de acceso
        if ($datos['es_exclusivo'] && empty($datos['codigo_acceso'])) {
            $errores[] = "Los cursos exclusivos deben tener un código de acceso";
        }

        // Verificar número de registro único
        $stmt = $pdo->prepare("SELECT id FROM cursos WHERE numero_registro = ? AND id != ?");
        $stmt->execute([$datos['numero_registro'], $curso_id]);
        if ($stmt->fetch()) {
            $errores[] = "El número de registro ya está en uso por otro curso";
        }

        // Si no hay errores, actualizar
        if (empty($errores)) {
            $stmt = $pdo->prepare("UPDATE cursos SET 
                nombre = :nombre, 
                descripcion = :descripcion, 
                fecha_inicio = :fecha_inicio, 
                fecha_fin = :fecha_fin, 
                cupo_maximo = :cupo_maximo, 
                numero_registro = :numero_registro,
                es_exclusivo = :es_exclusivo,
                codigo_acceso = :codigo_acceso
                WHERE id = :id");
            
            $datos['id'] = $curso_id;
            if ($stmt->execute($datos)) {
                $_SESSION['success'] = "Curso actualizado correctamente";
                header("Location: ver_cursos.php");
                ob_end_flush();
                exit();
            }
            throw new Exception("No se pudo actualizar el curso");
        }
        
        $_SESSION['error'] = implode("<br>", $errores);
        header("Location: editar_curso.php?id=$curso_id");
        ob_end_flush();
        exit();

    } catch (PDOException $e) {
        error_log("Error de base de datos: " . $e->getMessage());
        $_SESSION['error'] = "Error al guardar en la base de datos: " . $e->getMessage();
        header("Location: editar_curso.php?id=$curso_id");
        ob_end_flush();
        exit();
    } catch (Exception $e) {
        error_log("Error general: " . $e->getMessage());
        $_SESSION['error'] = "Error al procesar la solicitud: " . $e->getMessage();
        header("Location: editar_curso.php?id=$curso_id");
        ob_end_flush();
        exit();
    }
}

// Limpiar buffer antes de mostrar HTML
ob_clean();
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Editar Curso | ESIBOC</title>
    
    <!-- Google Font: Source Sans Pro -->
    <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,400i,700&display=fallback">
    <!-- Font Awesome Icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Theme style -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/css/adminlte.min.css">
    <style>
        .content-wrapper {
            background-color: #f4f6f9;
        }
        .card-primary.card-outline {
            border-top: 3px solid #007bff;
        }
        .section-title {
            font-size: 1.1rem;
            color: #007bff;
            margin-bottom: 1rem;
            padding-bottom: 0.5rem;
            border-bottom: 1px solid #dee2e6;
        }
        .form-group label {
            font-weight: 600;
            color: #495057;
        }
        .file-info {
            font-size: 0.8rem;
            color: #6c757d;
            margin-top: 0.25rem;
        }
        .required-field::after {
            content: " *";
            color: #dc3545;
        }
        .btn-group {
            display: flex;
            justify-content: flex-end;
            gap: 10px;
            margin-top: 20px;
        }
        .custom-switch .custom-control-label::before {
            width: 2.5rem;
            height: 1.25rem;
        }
        .custom-switch .custom-control-label::after {
            width: calc(1.25rem - 4px);
            height: calc(1.25rem - 4px);
        }
    </style>
</head>
<body class="hold-transition sidebar-mini">
<div class="wrapper">

    <!-- Navbar -->
    <nav class="main-header navbar navbar-expand navbar-white navbar-light">
        <ul class="navbar-nav">
            <li class="nav-item">
                <a class="nav-link" data-widget="pushmenu" href="#"><i class="fas fa-bars"></i></a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="dashboard.php" class="nav-link">Inicio</a>
            </li>
        </ul>
        <ul class="navbar-nav ml-auto">
            <li class="nav-item">
                <a class="nav-link" href="logout.php">
                    <i class="fas fa-sign-out-alt"></i> Cerrar Sesión
                </a>
            </li>
        </ul>
    </nav>

    <!-- Sidebar -->
    <aside class="main-sidebar sidebar-dark-primary elevation-4">
        <a href="dashboard.php" class="brand-link">
            <span class="brand-text font-weight-light">ESIBOC Admin</span>
        </a>
        <div class="sidebar">
            <div class="user-panel mt-3 pb-3 mb-3 d-flex">
                <div class="image">
                    <span class="img-circle elevation-2 bg-info d-flex align-items-center justify-content-center" 
                          style="width: 40px; height: 40px; font-weight: bold; font-size: 18px;">
                        <?= strtoupper(substr($_SESSION['admin_nombre'], 0, 1)) ?>
                    </span>
                </div>
                <div class="info">
                    <a href="#" class="d-block"><?= htmlspecialchars($_SESSION['admin_nombre']) ?></a>
                </div>
            </div>
            <nav class="mt-2">
                <ul class="nav nav-pills nav-sidebar flex-column" data-widget="treeview" role="menu" data-accordion="false">
                    <li class="nav-item">
                        <a href="dashboard.php" class="nav-link">
                            <i class="nav-icon fas fa-tachometer-alt"></i>
                            <p>Dashboard</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="crear_curso.php" class="nav-link">
                            <i class="nav-icon fas fa-plus-circle"></i>
                            <p>Crear Curso</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="ver_cursos.php" class="nav-link active">
                            <i class="nav-icon fas fa-book"></i>
                            <p>Gestionar Cursos</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="inscribir_participante.php" class="nav-link">
                            <i class="nav-icon fas fa-user-plus"></i>
                            <p>Inscribir Participante</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="ver_inscritos.php" class="nav-link">
                            <i class="nav-icon fas fa-clipboard-list"></i>
                            <p>Ver Inscripciones</p>
                        </a>
                    </li>
                </ul>
            </nav>
        </div>
    </aside>

    <!-- Content Wrapper -->
    <div class="content-wrapper">
        <div class="content-header">
            <div class="container-fluid">
                <div class="row mb-2">
                    <div class="col-sm-6">
                        <h1 class="m-0">Editar Curso</h1>
                    </div>
                    <div class="col-sm-6">
                        <ol class="breadcrumb float-sm-right">
                            <li class="breadcrumb-item"><a href="dashboard.php">Inicio</a></li>
                            <li class="breadcrumb-item"><a href="ver_cursos.php">Cursos</a></li>
                            <li class="breadcrumb-item active">Editar</li>
                        </ol>
                    </div>
                </div>
            </div>
        </div>

        <!-- Main content -->
        <section class="content">
            <div class="container-fluid">
                <!-- Mostrar mensajes -->
                <?php if (isset($_SESSION['error'])): ?>
                <div class="alert alert-danger alert-dismissible">
                    <button type="button" class="close" data-dismiss="alert" aria-hidden="true">×</button>
                    <h5><i class="icon fas fa-ban"></i> Error!</h5>
                    <?= $_SESSION['error']; unset($_SESSION['error']); ?>
                </div>
                <?php endif; ?>

                <?php if (isset($_SESSION['success'])): ?>
                <div class="alert alert-success alert-dismissible">
                    <button type="button" class="close" data-dismiss="alert" aria-hidden="true">×</button>
                    <h5><i class="icon fas fa-check"></i> Éxito!</h5>
                    <?= $_SESSION['success']; unset($_SESSION['success']); ?>
                </div>
                <?php endif; ?>

                <div class="row">
                    <div class="col-md-12">
                        <div class="card card-primary card-outline">
                            <div class="card-header">
                                <h3 class="card-title">
                                    <i class="fas fa-edit mr-2"></i>
                                    Formulario de Edición
                                </h3>
                            </div>
                            
                            <form method="POST" action="">
                                <div class="card-body">
                                    <!-- Sección Información Básica -->
                                    <div class="form-section mb-4">
                                        <h3 class="section-title"><i class="fas fa-info-circle me-2"></i>Información Básica</h3>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label for="nombre" class="required-field">Nombre del curso</label>
                                                    <input type="text" name="nombre" id="nombre" class="form-control" 
                                                           placeholder="Ej: Primeros Auxilios Avanzados" required 
                                                           value="<?= htmlspecialchars($curso['nombre']) ?>">
                                                </div>
                                            </div>
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <label for="numero_registro" class="required-field">Número de registro</label>
                                                    <input type="text" name="numero_registro" id="numero_registro" 
                                                           class="form-control" placeholder="Ej: CUR-2023-001" required
                                                           value="<?= htmlspecialchars($curso['numero_registro']) ?>">
                                                    <small class="text-muted">Identificador único del curso</small>
                                                </div>
                                            </div>
                                            <div class="col-12">
                                                <div class="form-group">
                                                    <label for="descripcion" class="required-field">Descripción</label>
                                                    <textarea name="descripcion" id="descripcion" class="form-control" 
                                                              rows="4" placeholder="Descripción detallada del curso..." 
                                                              required><?= htmlspecialchars($curso['descripcion']) ?></textarea>
                                                </div>
                                            </div>
                                        </div>
                                    </div>

                                    <!-- Sección Fechas y Cupos -->
                                    <div class="form-section mb-4">
                                        <h3 class="section-title"><i class="fas fa-calendar-alt me-2"></i>Fechas y Cupos</h3>
                                        <div class="row">
                                            <div class="col-md-4">
                                                <div class="form-group">
                                                    <label for="fecha_inicio" class="required-field">Fecha de inicio</label>
                                                    <input type="date" name="fecha_inicio" id="fecha_inicio" 
                                                           class="form-control" required
                                                           value="<?= htmlspecialchars($curso['fecha_inicio']) ?>">
                                                </div>
                                            </div>
                                            <div class="col-md-4">
                                                <div class="form-group">
                                                    <label for="fecha_fin" class="required-field">Fecha de fin</label>
                                                    <input type="date" name="fecha_fin" id="fecha_fin" 
                                                           class="form-control" required
                                                           value="<?= htmlspecialchars($curso['fecha_fin']) ?>">
                                                </div>
                                            </div>
                                            <div class="col-md-4">
                                                <div class="form-group">
                                                    <label for="cupo_maximo" class="required-field">Cupo máximo</label>
                                                    <input type="number" name="cupo_maximo" id="cupo_maximo" 
                                                           class="form-control" min="1" max="100" required
                                                           value="<?= htmlspecialchars($curso['cupo_maximo']) ?>">
                                                    <small class="text-muted">Máximo 100 participantes</small>
                                                </div>
                                            </div>
                                        </div>
                                    </div>

                                    <!-- Sección Configuración de Acceso -->
                                    <div class="form-section">
                                        <h3 class="section-title"><i class="fas fa-lock me-2"></i>Configuración de Acceso</h3>
                                        <div class="row">
                                            <div class="col-md-6">
                                                <div class="form-group">
                                                    <div class="custom-control custom-switch">
                                                        <input type="checkbox" class="custom-control-input" id="es_exclusivo" name="es_exclusivo" 
                                                               <?= $curso['es_exclusivo'] ? 'checked' : '' ?>>
                                                        <label class="custom-control-label" for="es_exclusivo">Curso exclusivo (requiere código de acceso)</label>
                                                    </div>
                                                </div>
                                            </div>
                                            <div class="col-md-6" id="codigo_acceso_container" style="<?= $curso['es_exclusivo'] ? '' : 'display: none;' ?>">
                                                <div class="form-group">
                                                    <label for="codigo_acceso">Código de acceso</label>
                                                    <input type="text" class="form-control" id="codigo_acceso" name="codigo_acceso" 
                                                           value="<?= htmlspecialchars($curso['codigo_acceso']) ?>" 
                                                           placeholder="Ej: BOMBEROS2023">
                                                    <small class="text-muted">Este código será requerido para inscribirse</small>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                
                                <div class="card-footer">
                                    <div class="btn-group">
                                        <a href="ver_cursos.php" class="btn btn-secondary">
                                            <i class="fas fa-times me-2"></i>Cancelar
                                        </a>
                                        <button type="submit" class="btn btn-primary">
                                            <i class="fas fa-save me-2"></i>Guardar Cambios
                                        </button>
                                    </div>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </section>
    </div>

    <!-- Footer -->
    <footer class="main-footer">
        <strong>Copyright &copy; <?= date('Y') ?> <a href="#">ESIBOC</a>.</strong>
        Todos los derechos reservados.
        <div class="float-right d-none d-sm-inline-block">
            <b>Versión</b> 1.0.0
        </div>
    </footer>
</div>

<!-- REQUIRED SCRIPTS -->
<script src="https://cdn.jsdelivr.net/npm/jquery@3.6.0/dist/jquery.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/js/bootstrap.bundle.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>
<script>
// Cerrar automáticamente las alertas después de 5 segundos
$(document).ready(function() {
    setTimeout(function() {
        $(".alert").fadeTo(500, 0).slideUp(500, function(){
            $(this).remove(); 
        });
    }, 5000);

    // Mostrar/ocultar campo de código de acceso
    $('#es_exclusivo').change(function() {
        if ($(this).is(':checked')) {
            $('#codigo_acceso_container').show();
            $('#codigo_acceso').prop('required', true);
        } else {
            $('#codigo_acceso_container').hide();
            $('#codigo_acceso').prop('required', false);
        }
    });

    // Validación del formulario
    $('form').submit(function() {
        if ($('#es_exclusivo').is(':checked') && $('#codigo_acceso').val().trim() === '') {
            alert('Los cursos exclusivos deben tener un código de acceso');
            return false;
        }
        return true;
    });
});
</script>
</body>
</html>
<?php
// Limpiar buffer al final
ob_end_flush();
?>