<?php
// Inicio seguro de sesión
if (session_status() !== PHP_SESSION_ACTIVE) {
    session_start();
}

// Verificación de autenticación
if (!isset($_SESSION['admin_id'])) {
    header("Location: login.php");
    exit;
}

// Conexión a base de datos
require_once '../config/database.php';

// Función para obtener lista de departamentos
function obtenerDepartamentos() {
    return [
        'Amazonas', 'Antioquia', 'Arauca', 'Atlántico', 'Bolívar', 'Boyacá', 
        'Caldas', 'Caquetá', 'Casanare', 'Cauca', 'Cesar', 'Chocó', 
        'Córdoba', 'Cundinamarca', 'Guainía', 'Guaviare', 'Huila', 
        'La Guajira', 'Magdalena', 'Meta', 'Nariño', 'Norte de Santander', 
        'Putumayo', 'Quindío', 'Risaralda', 'San Andrés y Providencia', 
        'Santander', 'Sucre', 'Tolima', 'Valle del Cauca', 'Vaupés', 'Vichada'
    ];
}

// Función para obtener la ruta correcta de la foto
function getFotoParticipante($participante, $pdo) {
    if (empty($participante['archivo_img_fotografia'])) {
        return false;
    }
    
    // Primero verificar si la ruta almacenada es válida
    if (file_exists($participante['archivo_img_fotografia']) && is_readable($participante['archivo_img_fotografia'])) {
        return $participante['archivo_img_fotografia'];
    }
    
    // Si no, intentar construir la ruta basada en la estructura de carpetas
    try {
        // Obtener información de los cursos del participante
        $stmt = $pdo->prepare("
            SELECT c.nombre, c.numero_registro 
            FROM cursos c
            JOIN inscripciones i ON c.id = i.curso_id
            WHERE i.participante_id = ?
            LIMIT 1
        ");
        $stmt->execute([$participante['id']]);
        $curso = $stmt->fetch(PDO::FETCH_ASSOC);
        
        if ($curso) {
            $base_path = '../cursos/';
            $curso_folder = preg_replace('/[^A-Za-z0-9\-]/', '', str_replace(' ', '_', $curso['nombre'])) . '_' . $curso['numero_registro'];
            $participante_folder = preg_replace('/[^A-Za-z0-9\-]/', '', str_replace(' ', '_', $participante['nombres'] . '_' . $participante['apellidos'])) . '_' . $participante['cedula'];
            
            $ruta_completa = $base_path . $curso_folder . '/' . $participante_folder . '/' . $participante['archivo_img_fotografia'];
            
            if (file_exists($ruta_completa) && is_readable($ruta_completa)) {
                return $ruta_completa;
            }
        }
    } catch (Exception $e) {
        error_log("Error al obtener ruta de foto: " . $e->getMessage());
    }
    
    return false;
}

// Validar ID del participante
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    $_SESSION['flash_message'] = [
        'type' => 'danger',
        'message' => 'ID de participante inválido.'
    ];
    header("Location: ver_inscritos.php");
    exit;
}

$participante_id = (int)$_GET['id'];

// Obtener datos del participante
try {
    $stmt = $pdo->prepare("SELECT * FROM participantes WHERE id = ?");
    $stmt->execute([$participante_id]);
    $participante = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$participante) {
        $_SESSION['flash_message'] = [
            'type' => 'danger',
            'message' => 'Participante no encontrado.'
        ];
        header("Location: ver_inscritos.php");
        exit;
    }

    // Obtener la ruta correcta de la foto
    $participante['foto_ruta'] = getFotoParticipante($participante, $pdo);

    // Obtener cursos inscritos por el participante
    $stmtCursos = $pdo->prepare("
        SELECT c.id, c.nombre, i.fecha_inscripcion 
        FROM inscripciones i
        JOIN cursos c ON i.curso_id = c.id
        WHERE i.participante_id = ?
        ORDER BY c.fecha_inicio DESC
    ");
    $stmtCursos->execute([$participante_id]);
    $cursos_inscritos = $stmtCursos->fetchAll(PDO::FETCH_ASSOC);

} catch (Exception $e) {
    $_SESSION['flash_message'] = [
        'type' => 'danger',
        'message' => 'Error al obtener datos: ' . $e->getMessage()
    ];
    header("Location: ver_inscritos.php");
    exit;
}

// Procesar actualización
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    try {
        // Directorio para subir archivos
        $uploadDir = '../uploads/';
        if (!file_exists($uploadDir)) {
            mkdir($uploadDir, 0777, true);
        }

        // Procesar nueva foto si se subió
        $nuevaFoto = $participante['archivo_img_fotografia'];
        if (isset($_FILES['nueva_foto']) && $_FILES['nueva_foto']['error'] === UPLOAD_ERR_OK) {
            // Validar tipo de archivo
            $allowedTypes = ['image/jpeg', 'image/png', 'image/gif'];
            $fileType = mime_content_type($_FILES['nueva_foto']['tmp_name']);
            
            if (!in_array($fileType, $allowedTypes)) {
                throw new Exception("Solo se permiten archivos de imagen (JPEG, PNG, GIF)");
            }

            // Eliminar foto anterior si existe
            if (!empty($participante['archivo_img_fotografia'])) {
                // Intentar eliminar la foto en la ruta original
                if (file_exists($participante['archivo_img_fotografia'])) {
                    @unlink($participante['archivo_img_fotografia']);
                }
                // Intentar eliminar la foto en la ruta construida
                if (!empty($participante['foto_ruta']) && file_exists($participante['foto_ruta'])) {
                    @unlink($participante['foto_ruta']);
                }
            }

            // Subir nueva foto
            $ext = pathinfo($_FILES['nueva_foto']['name'], PATHINFO_EXTENSION);
            $nombreFoto = 'foto_' . uniqid() . '.' . $ext;
            $rutaFoto = $uploadDir . $nombreFoto;
            
            if (move_uploaded_file($_FILES['nueva_foto']['tmp_name'], $rutaFoto)) {
                $nuevaFoto = $rutaFoto;
            } else {
                throw new Exception("Error al subir la nueva foto");
            }
        }

        // Validar y sanitizar datos
        $datos = [
            'nombres' => trim($_POST['nombres']),
            'apellidos' => trim($_POST['apellidos']),
            'cedula' => trim($_POST['cedula']),
            'sexo' => $_POST['sexo'],
            'celular' => trim($_POST['celular']),
            'correo' => trim($_POST['correo']),
            'direccion' => trim($_POST['direccion']),
            'departamento' => $_POST['departamento'],
            'municipio' => $_POST['municipio'],
            'clase_cuerpo_bomberos' => $_POST['clase_cuerpo_bomberos'],
            'archivo_img_fotografia' => $nuevaFoto,
            'id' => $participante_id
        ];

        // Validaciones adicionales
        if (empty($datos['nombres']) || empty($datos['apellidos']) || empty($datos['cedula'])) {
            throw new Exception("Los campos nombres, apellidos y cédula son obligatorios");
        }

        if (!preg_match('/^\d{6,12}$/', $datos['cedula'])) {
            throw new Exception("La cédula debe contener entre 6 y 12 dígitos");
        }

        if (!filter_var($datos['correo'], FILTER_VALIDATE_EMAIL)) {
            throw new Exception("El correo electrónico no es válido");
        }

        // Actualizar en base de datos
        $stmtUpdate = $pdo->prepare("
            UPDATE participantes SET 
                nombres = :nombres,
                apellidos = :apellidos,
                cedula = :cedula,
                sexo = :sexo,
                celular = :celular,
                correo = :correo,
                direccion = :direccion,
                departamento = :departamento,
                municipio = :municipio,
                clase_cuerpo_bomberos = :clase_cuerpo_bomberos,
                archivo_img_fotografia = :archivo_img_fotografia
            WHERE id = :id
        ");

        if ($stmtUpdate->execute($datos)) {
            $_SESSION['flash_message'] = [
                'type' => 'success',
                'message' => 'Participante actualizado correctamente.'
            ];
            header("Location: editar_participante.php?id=" . $participante_id);
            exit;
        } else {
            throw new Exception("Error al ejecutar la actualización en la base de datos");
        }

    } catch (Exception $e) {
        $_SESSION['flash_message'] = [
            'type' => 'danger',
            'message' => 'Error al actualizar: ' . $e->getMessage()
        ];
    }
}

// Obtener lista de departamentos para el select
$departamentos = obtenerDepartamentos();
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Editar Participante | ESIBOC</title>
    
    <!-- Google Font: Source Sans Pro -->
    <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,400i,700&display=fallback">
    <!-- Font Awesome Icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Theme style -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/css/adminlte.min.css">
    <!-- Select2 -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/select2-bootstrap-5-theme@1.3.0/dist/select2-bootstrap-5-theme.min.css">
    <style>
        .user-panel .info {
            display: inline-block;
            padding: 5px 5px 5px 10px;
        }
        .brand-link {
            border-bottom: none !important;
        }
        .participant-photo-container {
            text-align: center;
            margin-bottom: 20px;
        }
        .participant-photo {
            width: 150px;
            height: 150px;
            border-radius: 50%;
            object-fit: cover;
            background-color: #6c757d;
            color: white;
            display: flex;
            align-items: center;
            justify-content: center;
            font-weight: bold;
            font-size: 48px;
            margin: 0 auto;
            border: 3px solid #dee2e6;
        }
        .participant-photo img {
            width: 100%;
            height: 100%;
            border-radius: 50%;
            object-fit: cover;
        }
        .course-badge {
            margin-right: 5px;
            margin-bottom: 5px;
        }
        .file-upload {
            position: relative;
            overflow: hidden;
            display: inline-block;
        }
        .file-upload-input {
            position: absolute;
            left: 0;
            top: 0;
            opacity: 0;
            width: 100%;
            height: 100%;
            cursor: pointer;
        }
        .file-upload-label {
            display: block;
            padding: 6px 12px;
            background-color: #6c757d;
            color: white;
            border-radius: 4px;
            text-align: center;
            cursor: pointer;
            margin-top: 10px;
        }
        .file-upload-label:hover {
            background-color: #5a6268;
        }
        .select2-container--bootstrap-5 .select2-selection {
            min-height: 38px;
            padding: 5px;
        }
        .select2-container--bootstrap-5 .select2-selection--single .select2-selection__rendered {
            padding-left: 5px;
        }
        .no-photo {
            background-color: #6c757d;
            color: white;
        }
    </style>
</head>
<body class="hold-transition sidebar-mini layout-fixed">
<div class="wrapper">

    <!-- Navbar -->
    <nav class="main-header navbar navbar-expand navbar-white navbar-light">
        <!-- Left navbar links -->
        <ul class="navbar-nav">
            <li class="nav-item">
                <a class="nav-link" data-widget="pushmenu" href="#" role="button"><i class="fas fa-bars"></i></a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="dashboard.php" class="nav-link">Inicio</a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="ver_inscritos.php" class="nav-link">Inscripciones</a>
            </li>
        </ul>

        <!-- Right navbar links -->
        <ul class="navbar-nav ml-auto">
            <li class="nav-item">
                <a class="nav-link" href="logout.php" role="button">
                    <i class="fas fa-sign-out-alt"></i> Cerrar Sesión
                </a>
            </li>
        </ul>
    </nav>
    <!-- /.navbar -->

    <!-- Main Sidebar Container -->
    <aside class="main-sidebar sidebar-dark-primary elevation-4">
        <!-- Brand Logo -->
        <a href="dashboard.php" class="brand-link">
            <span class="brand-text font-weight-light">ESIBOC Admin</span>
        </a>

        <!-- Sidebar -->
        <div class="sidebar">
            <!-- Sidebar user panel (optional) -->
            <div class="user-panel mt-3 pb-3 mb-3 d-flex">
                <div class="image">
                    <span class="img-circle elevation-2 bg-info d-flex align-items-center justify-content-center" 
                          style="width: 40px; height: 40px; font-weight: bold; font-size: 18px;">
                        <?= strtoupper(substr($_SESSION['admin_nombre'], 0, 1)) ?>
                    </span>
                </div>
                <div class="info">
                    <a href="#" class="d-block"><?= htmlspecialchars($_SESSION['admin_nombre']) ?></a>
                </div>
            </div>

            <!-- Sidebar Menu -->
            <nav class="mt-2">
                <ul class="nav nav-pills nav-sidebar flex-column" data-widget="treeview" role="menu" data-accordion="false">
                    <li class="nav-item">
                        <a href="dashboard.php" class="nav-link">
                            <i class="nav-icon fas fa-tachometer-alt"></i>
                            <p>Dashboard</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="crear_curso.php" class="nav-link">
                            <i class="nav-icon fas fa-plus-circle"></i>
                            <p>Crear Curso</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="ver_cursos.php" class="nav-link">
                            <i class="nav-icon fas fa-book"></i>
                            <p>Gestionar Cursos</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="inscribir_participante.php" class="nav-link">
                            <i class="nav-icon fas fa-user-plus"></i>
                            <p>Inscribir Participante</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="ver_inscritos.php" class="nav-link active">
                            <i class="nav-icon fas fa-clipboard-list"></i>
                            <p>Ver Inscripciones</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="logout.php" class="nav-link text-danger">
                            <i class="nav-icon fas fa-sign-out-alt"></i>
                            <p>Cerrar Sesión</p>
                        </a>
                    </li>
                </ul>
            </nav>
            <!-- /.sidebar-menu -->
        </div>
        <!-- /.sidebar -->
    </aside>

    <!-- Content Wrapper. Contains page content -->
    <div class="content-wrapper">
        <!-- Content Header (Page header) -->
        <div class="content-header">
            <div class="container-fluid">
                <div class="row mb-2">
                    <div class="col-sm-6">
                        <h1 class="m-0">Editar Participante</h1>
                    </div>
                    <div class="col-sm-6">
                        <ol class="breadcrumb float-sm-right">
                            <li class="breadcrumb-item"><a href="dashboard.php">Inicio</a></li>
                            <li class="breadcrumb-item"><a href="ver_inscritos.php">Inscripciones</a></li>
                            <li class="breadcrumb-item active">Editar</li>
                        </ol>
                    </div>
                </div>
            </div>
        </div>

        <!-- Main content -->
        <section class="content">
            <div class="container-fluid">
                <div class="row">
                    <div class="col-md-12">
                        <?php if (isset($_SESSION['flash_message'])): ?>
                            <div class="alert alert-<?= $_SESSION['flash_message']['type'] ?> alert-dismissible">
                                <button type="button" class="close" data-dismiss="alert" aria-hidden="true">×</button>
                                <?= $_SESSION['flash_message']['message'] ?>
                            </div>
                            <?php unset($_SESSION['flash_message']); ?>
                        <?php endif; ?>

                        <div class="card card-primary">
                            <div class="card-header">
                                <h3 class="card-title">Información del Participante</h3>
                            </div>
                            <!-- /.card-header -->
                            <form method="POST" action="" enctype="multipart/form-data">
                                <div class="card-body">
                                    <div class="row">
                                        <div class="col-md-3">
                                            <div class="participant-photo-container">
                                                <?php if (!empty($participante['foto_ruta'])): ?>
                                                    <div class="participant-photo">
                                                        <img src="<?= htmlspecialchars($participante['foto_ruta']) ?>" 
                                                             alt="Foto de <?= htmlspecialchars($participante['nombres'] . ' ' . $participante['apellidos']) ?>">
                                                    </div>
                                                <?php else: ?>
                                                    <div class="participant-photo no-photo">
                                                        <?= strtoupper(substr($participante['nombres'], 0, 1) . substr($participante['apellidos'], 0, 1)) ?>
                                                    </div>
                                                <?php endif; ?>
                                                
                                                <div class="file-upload">
                                                    <label for="nueva_foto" class="file-upload-label">
                                                        <i class="fas fa-camera"></i> Cambiar Foto
                                                    </label>
                                                    <input type="file" id="nueva_foto" name="nueva_foto" class="file-upload-input" accept="image/*">
                                                </div>
                                                
                                                <div class="text-center mt-3">
                                                    <h4><?= htmlspecialchars($participante['nombres'] . ' ' . $participante['apellidos']) ?></h4>
                                                    <p class="text-muted">Cédula: <?= htmlspecialchars($participante['cedula']) ?></p>
                                                </div>
                                                
                                                <?php if (!empty($cursos_inscritos)): ?>
                                                    <div class="mt-4">
                                                        <h5>Cursos Inscritos:</h5>
                                                        <?php foreach ($cursos_inscritos as $curso): ?>
                                                            <span class="badge badge-primary course-badge">
                                                                <?= htmlspecialchars($curso['nombre']) ?>
                                                            </span>
                                                        <?php endforeach; ?>
                                                    </div>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                        <div class="col-md-9">
                                            <div class="row">
                                                <div class="col-md-6">
                                                    <div class="form-group">
                                                        <label for="nombres">Nombres *</label>
                                                        <input type="text" class="form-control" id="nombres" name="nombres" 
                                                               value="<?= htmlspecialchars($participante['nombres']) ?>" required>
                                                    </div>
                                                </div>
                                                <div class="col-md-6">
                                                    <div class="form-group">
                                                        <label for="apellidos">Apellidos *</label>
                                                        <input type="text" class="form-control" id="apellidos" name="apellidos" 
                                                               value="<?= htmlspecialchars($participante['apellidos']) ?>" required>
                                                    </div>
                                                </div>
                                            </div>
                                            
                                            <div class="row">
                                                <div class="col-md-4">
                                                    <div class="form-group">
                                                        <label for="cedula">Cédula *</label>
                                                        <input type="text" class="form-control" id="cedula" name="cedula" 
                                                               value="<?= htmlspecialchars($participante['cedula']) ?>" required>
                                                    </div>
                                                </div>
                                                <div class="col-md-4">
                                                    <div class="form-group">
                                                        <label for="sexo">Sexo *</label>
                                                        <select class="form-control" id="sexo" name="sexo" required>
                                                            <option value="Masculino" <?= $participante['sexo'] === 'Masculino' ? 'selected' : '' ?>>Masculino</option>
                                                            <option value="Femenino" <?= $participante['sexo'] === 'Femenino' ? 'selected' : '' ?>>Femenino</option>
                                                            <option value="Otro" <?= $participante['sexo'] === 'Otro' ? 'selected' : '' ?>>Otro</option>
                                                        </select>
                                                    </div>
                                                </div>
                                                <div class="col-md-4">
                                                    <div class="form-group">
                                                        <label for="celular">Celular *</label>
                                                        <input type="tel" class="form-control" id="celular" name="celular" 
                                                               value="<?= htmlspecialchars($participante['celular']) ?>" required>
                                                    </div>
                                                </div>
                                            </div>
                                            
                                            <div class="form-group">
                                                <label for="correo">Correo Electrónico *</label>
                                                <input type="email" class="form-control" id="correo" name="correo" 
                                                       value="<?= htmlspecialchars($participante['correo']) ?>" required>
                                            </div>
                                            
                                            <div class="form-group">
                                                <label for="direccion">Dirección *</label>
                                                <input type="text" class="form-control" id="direccion" name="direccion" 
                                                       value="<?= htmlspecialchars($participante['direccion']) ?>" required>
                                            </div>
                                            
                                            <div class="row">
                                                <div class="col-md-6">
                                                    <div class="form-group">
                                                        <label for="departamento">Departamento *</label>
                                                        <select class="form-control select2" id="departamento" name="departamento" required style="width: 100%;">
                                                            <option value="">Seleccionar departamento...</option>
                                                            <?php foreach ($departamentos as $depto): ?>
                                                                <option value="<?= htmlspecialchars($depto) ?>" 
                                                                    <?= ($participante['departamento'] === $depto) ? 'selected' : '' ?>>
                                                                    <?= htmlspecialchars($depto) ?>
                                                                </option>
                                                            <?php endforeach; ?>
                                                        </select>
                                                    </div>
                                                </div>
                                                <div class="col-md-6">
                                                    <div class="form-group">
                                                        <label for="municipio">Municipio *</label>
                                                        <select class="form-control select2" id="municipio" name="municipio" required style="width: 100%;">
                                                            <option value="">Seleccionar municipio...</option>
                                                            <?php if (!empty($participante['municipio'])): ?>
                                                                <option value="<?= htmlspecialchars($participante['municipio']) ?>" selected>
                                                                    <?= htmlspecialchars($participante['municipio']) ?>
                                                                </option>
                                                            <?php endif; ?>
                                                        </select>
                                                    </div>
                                                </div>
                                            </div>
                                            
                                            <div class="form-group">
                                                <label for="clase_cuerpo_bomberos">Clase de Cuerpo de Bomberos *</label>
                                                <select class="form-control" id="clase_cuerpo_bomberos" name="clase_cuerpo_bomberos" required>
                                                    <option value="">Seleccione una opción</option>
                                                    <option value="Voluntario" <?= $participante['clase_cuerpo_bomberos'] === 'Voluntario' ? 'selected' : '' ?>>Voluntario</option>
                                                    <option value="Oficial" <?= $participante['clase_cuerpo_bomberos'] === 'Oficial' ? 'selected' : '' ?>>Oficial</option>
                                                    <option value="Aeronautico" <?= $participante['clase_cuerpo_bomberos'] === 'Aeronautico' ? 'selected' : '' ?>>Aeronautico</option>
                                                </select>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <!-- /.card-body -->

                                <div class="card-footer">
                                    <button type="submit" class="btn btn-primary">
                                        <i class="fas fa-save"></i> Guardar Cambios
                                    </button>
                                    <a href="ver_inscritos.php" class="btn btn-default float-right">
                                        <i class="fas fa-times"></i> Cancelar
                                    </a>
                                </div>
                            </form>
                        </div>
                        <!-- /.card -->
                    </div>
                </div>
            </div><!-- /.container-fluid -->
        </section>
        <!-- /.content -->
    </div>
    <!-- /.content-wrapper -->

    <!-- Main Footer -->
    <footer class="main-footer">
        <strong>Copyright &copy; <?= date('Y') ?> <a href="#">ESIBOC</a>.</strong>
        Todos los derechos reservados.
        <div class="float-right d-none d-sm-inline-block">
            <b>Versión</b> 1.0.0
        </div>
    </footer>
</div>
<!-- ./wrapper -->

<!-- REQUIRED SCRIPTS -->
<!-- jQuery -->
<script src="https://cdn.jsdelivr.net/npm/jquery@3.6.0/dist/jquery.min.js"></script>
<!-- Bootstrap 4 -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/js/bootstrap.bundle.min.js"></script>
<!-- AdminLTE App -->
<script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>
<!-- Select2 -->
<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
<!-- Custom scripts -->
<script>
    $(function () {
        // Inicializar Select2
        $('.select2').select2({
            theme: 'bootstrap-5',
            width: '100%',
            dropdownParent: $('.card-body'),
            placeholder: $(this).data('placeholder'),
            allowClear: Boolean($(this).data('allow-clear')),
            closeOnSelect: !$(this).attr('multiple')
        });

        // Cargar municipios cuando cambie el departamento
        $('#departamento').change(function() {
            var departamento = $(this).val();
            var $municipioSelect = $('#municipio');
            
            $municipioSelect.empty().append('<option value="">Seleccionar municipio...</option>');
            $municipioSelect.val('').trigger('change');
            
            if (departamento) {
                // Hacer llamada AJAX al servidor para obtener municipios
                $.getJSON('obtener_municipios.php', {departamento: departamento}, function(data) {
                    $.each(data, function(index, municipio) {
                        $municipioSelect.append(new Option(municipio, municipio));
                    });
                    
                    // Seleccionar el municipio actual si existe
                    var municipioActual = '<?= $participante["municipio"] ?? "" ?>';
                    if (municipioActual) {
                        $municipioSelect.val(municipioActual).trigger('change');
                    }
                }).fail(function(jqXHR, textStatus, errorThrown) {
                    console.error('Error al cargar municipios:', textStatus, errorThrown);
                });
            }
        });

        // Mostrar vista previa de la nueva foto
        $('#nueva_foto').change(function() {
            if (this.files && this.files[0]) {
                var reader = new FileReader();
                
                reader.onload = function(e) {
                    $('.participant-photo').html('<img src="' + e.target.result + '" alt="Nueva foto">');
                }
                
                reader.readAsDataURL(this.files[0]);
            }
        });

        // Disparar evento change si ya hay un departamento seleccionado
        var departamentoActual = '<?= $participante["departamento"] ?? "" ?>';
        if (departamentoActual) {
            $('#departamento').trigger('change');
        }
    });
</script>
</body>
</html>