<?php
// eliminar_inscripcion.php

// 1. Configuración inicial
ob_start();

// 2. Manejo de sesión
if (session_status() !== PHP_SESSION_ACTIVE) {
    session_start();
}

// 3. Verificación de autenticación
if (!isset($_SESSION['admin_id'])) {
    ob_end_clean();
    header("Location: login.php");
    exit;
}

// 4. Conexión a base de datos
require_once __DIR__ . '/../config/database.php';

// 5. Validación de parámetros
if (!isset($_GET['participante_id'], $_GET['curso_id']) || 
    !filter_var($_GET['participante_id'], FILTER_VALIDATE_INT) || 
    !filter_var($_GET['curso_id'], FILTER_VALIDATE_INT)) {
    
    ob_end_clean();
    $_SESSION['flash_message'] = [
        'type' => 'danger',
        'message' => 'Parámetros inválidos para eliminar la inscripción'
    ];
    header("Location: ver_cursos.php");
    exit;
}

$participante_id = (int)$_GET['participante_id'];
$curso_id = (int)$_GET['curso_id'];

try {
    // 6. Obtener información necesaria para eliminar la carpeta
    $infoSql = "SELECT 
                    p.nombres, 
                    p.apellidos, 
                    p.cedula,
                    p.archivo_img_fotografia,
                    c.nombre AS curso_nombre,
                    c.numero_registro AS curso_numero
                FROM participantes p
                JOIN inscripciones i ON p.id = i.participante_id
                JOIN cursos c ON i.curso_id = c.id
                WHERE p.id = ? AND i.curso_id = ?";
    
    $infoStmt = $pdo->prepare($infoSql);
    $infoStmt->execute([$participante_id, $curso_id]);
    $info = $infoStmt->fetch(PDO::FETCH_ASSOC);

    if (!$info) {
        throw new Exception("No se encontró la inscripción especificada");
    }

    // 7. Iniciar transacción
    $pdo->beginTransaction();

    // 8. Eliminar la inscripción
    $deleteSql = "DELETE FROM inscripciones WHERE participante_id = ? AND curso_id = ?";
    $deleteStmt = $pdo->prepare($deleteSql);
    $deleteStmt->execute([$participante_id, $curso_id]);

    // 9. Eliminar archivos y carpeta del participante
    $base_path = '../cursos/';
    $curso_folder = preg_replace('/[^A-Za-z0-9\-]/', '', str_replace(' ', '_', $info['curso_nombre'])) . '_' . $info['curso_numero'];
    $participante_folder = preg_replace('/[^A-Za-z0-9\-]/', '', str_replace(' ', '_', $info['nombres'] . '_' . $info['apellidos'])) . '_' . $info['cedula'];
    
    $ruta_completa = $base_path . $curso_folder . '/' . $participante_folder;
    
    // 10. Eliminar archivos y carpeta si existen
    if (file_exists($ruta_completa) && is_dir($ruta_completa)) {
        // Eliminar todos los archivos del directorio primero
        $files = glob($ruta_completa . '/*');
        foreach ($files as $file) {
            if (is_file($file)) {
                unlink($file);
            }
        }
        // Eliminar el directorio
        rmdir($ruta_completa);
    }

    // 11. Confirmar transacción
    $pdo->commit();

    // 12. Preparar respuesta exitosa
    ob_end_clean();
    $_SESSION['flash_message'] = [
        'type' => 'success',
        'message' => 'Inscripción eliminada y carpeta del participante borrada correctamente.'
    ];

    // 13. Redirección
    header("Location: ver_inscritos.php?curso_id=" . $curso_id);
    exit;

} catch (PDOException $e) {
    // 14. Manejo de errores con rollback
    if (isset($pdo) && $pdo->inTransaction()) {
        $pdo->rollBack();
    }
    
    ob_end_clean();
    $_SESSION['flash_message'] = [
        'type' => 'danger',
        'message' => 'Error del sistema: ' . $e->getMessage()
    ];
    header("Location: ver_inscritos.php?curso_id=" . $curso_id);
    exit;
} catch (Exception $e) {
    ob_end_clean();
    $_SESSION['flash_message'] = [
        'type' => 'danger',
        'message' => 'Error: ' . $e->getMessage()
    ];
    header("Location: ver_inscritos.php?curso_id=" . $curso_id);
    exit;
}
?>