<?php
// Activar reporte de errores (solo para desarrollo)
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Iniciar buffer de salida
ob_start();

// Iniciar sesión
session_start();

// Configurar rutas base
$protocol = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on') ? 'https://' : 'http://';
$base_url = $protocol . $_SERVER['HTTP_HOST'] . '/esiboc';

// Incluir configuración de base de datos
require_once __DIR__ . '/../config/database.php';

// Redirigir si ya está logueado
if (isset($_SESSION['admin_id'])) {
    header("Location: $base_url/admin/dashboard.php");
    exit;
}

// Variable para mensajes de error
$error = null;

// Procesar formulario de login
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    try {
        // Validar campos
        if (empty($_POST['correo']) || empty($_POST['password'])) {
            throw new Exception("Todos los campos son requeridos");
        }

        // Obtener y limpiar datos
        $correo = filter_var($_POST['correo'], FILTER_SANITIZE_EMAIL);
        $password = $_POST['password'];

        // Buscar administrador
        $stmt = $pdo->prepare("SELECT * FROM admins WHERE correo = ? LIMIT 1");
        $stmt->execute([$correo]);
        $admin = $stmt->fetch(PDO::FETCH_ASSOC);

        // Verificar credenciales
        if (!$admin || !password_verify($password, $admin['password'])) {
            throw new Exception("Credenciales incorrectas");
        }

        // Configurar sesión
        $_SESSION['admin_id'] = $admin['id'];
        $_SESSION['admin_nombre'] = $admin['nombre'];
        $_SESSION['admin_correo'] = $admin['correo'];
        $_SESSION['admin_rol'] = $admin['rol'];
        $_SESSION['last_login'] = time();

        // Regenerar ID de sesión
        session_regenerate_id(true);

        // Limpiar buffer y redirigir
        ob_end_clean();
        header("Location: $base_url/admin/dashboard.php");
        exit;

    } catch (Exception $e) {
        $error = $e->getMessage();
        // Pequeño retraso para seguridad
        sleep(1);
    }
}

// Limpiar buffer si no se redirigió
ob_end_flush();
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Acceso Administrativo | ESIBOC</title>
    <link rel="stylesheet" href="<?php echo $base_url; ?>/admin/css/font-awesome.min.css">
    <style>
        :root {
            --primary: #3498db;
            --primary-dark: #2980b9;
            --danger: #e74c3c;
            --light: #ecf0f1;
            --dark: #2c3e50;
            --border-radius: 8px;
            --shadow: 0 4px 6px rgba(0, 0, 0, 0.1);
        }
        
        body {
            font-family: 'Segoe UI', Tahoma, sans-serif;
            background-color: #f5f7fa;
            display: flex;
            justify-content: center;
            align-items: center;
            min-height: 100vh;
            margin: 0;
            padding: 20px;
        }
        
        .login-container {
            background: white;
            width: 100%;
            max-width: 400px;
            padding: 2rem;
            border-radius: var(--border-radius);
            box-shadow: var(--shadow);
            text-align: center;
        }
        
        .logo {
            max-height: 80px;
            margin-bottom: 1.5rem;
        }
        
        h1 {
            color: var(--dark);
            margin-bottom: 1.5rem;
            font-size: 1.5rem;
        }
        
        .form-group {
            margin-bottom: 1.2rem;
            text-align: left;
        }
        
        label {
            display: block;
            margin-bottom: 0.5rem;
            color: var(--dark);
            font-weight: 500;
        }
        
        input {
            width: 100%;
            padding: 0.8rem;
            border: 1px solid #ddd;
            border-radius: 4px;
            font-size: 1rem;
            transition: border 0.3s;
        }
        
        input:focus {
            outline: none;
            border-color: var(--primary);
        }
        
        .btn {
            width: 100%;
            padding: 0.8rem;
            background: var(--primary);
            color: white;
            border: none;
            border-radius: 4px;
            font-size: 1rem;
            cursor: pointer;
            transition: background 0.3s;
        }
        
        .btn:hover {
            background: var(--primary-dark);
        }
        
        .alert {
            padding: 0.8rem;
            margin-bottom: 1rem;
            border-radius: 4px;
            background-color: #f8d7da;
            color: var(--danger);
            animation: fadeIn 0.3s;
        }
        
        @keyframes fadeIn {
            from { opacity: 0; }
            to { opacity: 1; }
        }
        
        .links {
            margin-top: 1.5rem;
            font-size: 0.9rem;
        }
        
        .links a {
            color: var(--primary);
            text-decoration: none;
        }
        
        .links a:hover {
            text-decoration: underline;
        }
    </style>
</head>
<body>
    <div class="login-container">
        <img src="<?php echo $base_url; ?>/assets/img/logo.png" alt="ESIBOC" class="logo">
        <h1>Acceso Administrativo</h1>
        
        <?php if ($error): ?>
            <div class="alert">
                <i class="fa fa-exclamation-circle"></i> <?php echo htmlspecialchars($error); ?>
            </div>
        <?php endif; ?>
        
        <form method="POST" action="<?php echo $base_url; ?>/admin/login.php">
            <div class="form-group">
                <label for="correo">Correo electrónico</label>
                <input type="email" id="correo" name="correo" placeholder="admin@esiboc.edu" required>
            </div>
            
            <div class="form-group">
                <label for="password">Contraseña</label>
                <input type="password" id="password" name="password" placeholder="••••••••" required>
            </div>
            
            <button type="submit" class="btn">
                <i class="fa fa-sign-in-alt"></i> Ingresar
            </button>
            
            <div class="links">
                <a href="<?php echo $base_url; ?>/admin/forgot-password.php">¿Olvidó su contraseña?</a>
            </div>
        </form>
    </div>

    <script>
        // Validación del lado del cliente
        document.querySelector('form').addEventListener('submit', function(e) {
            const correo = document.getElementById('correo').value.trim();
            const password = document.getElementById('password').value.trim();
            
            if (!correo || !password) {
                e.preventDefault();
                alert('Por favor complete todos los campos');
                return false;
            }
            
            if (!/^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(correo)) {
                e.preventDefault();
                alert('Por favor ingrese un correo válido');
                return false;
            }
            
            return true;
        });
    </script>
</body>
</html>