<?php
// Iniciar buffer para evitar errores de headers
ob_start();

// Configuración de errores (quitar en producción)
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Iniciar sesión segura
if (session_status() !== PHP_SESSION_ACTIVE) {
    session_start();
}

// Verificar autenticación
if (!isset($_SESSION['admin_id'])) {
    ob_end_clean();
    header("Location: login.php");
    exit;
}

// Conexión a base de datos
require_once '../config/database.php';

// Generar token CSRF seguro
if (empty($_SESSION['csrf_token'])) {
    $_SESSION['csrf_token'] = bin2hex(random_bytes(32));
}

try {
    // Consulta para contar cursos
    $sqlCount = "SELECT COUNT(*) as total FROM cursos";
    $stmtCount = $pdo->query($sqlCount);
    $totalCursos = $stmtCount->fetch(PDO::FETCH_ASSOC)['total'];

    // Configurar paginación
    $itemsPorPagina = 10;
    $paginaActual = isset($_GET['pagina']) ? (int)$_GET['pagina'] : 1;
    $offset = ($paginaActual - 1) * $itemsPorPagina;
    $totalPaginas = ceil($totalCursos / $itemsPorPagina);

    // Consulta principal con parámetros bindeados
    $sql = "SELECT 
                c.id,
                c.nombre,
                c.numero_registro,
                c.fecha_inicio,
                c.fecha_fin,
                c.cupo_maximo,
                c.habilitado,
                COUNT(i.id) AS inscritos,
                (c.cupo_maximo - COUNT(i.id)) AS cupos_disponibles,
                CASE 
                    WHEN c.fecha_inicio > CURDATE() THEN 'PRÓXIMO'
                    WHEN c.fecha_fin < CURDATE() THEN 'FINALIZADO'
                    WHEN (c.cupo_maximo - COUNT(i.id)) <= 0 THEN 'CUPO LLENO'
                    ELSE 'DISPONIBLE'
                END AS estado
            FROM cursos c
            LEFT JOIN inscripciones i ON c.id = i.curso_id
            GROUP BY c.id
            ORDER BY 
                CASE 
                    WHEN c.fecha_inicio > CURDATE() THEN 1
                    WHEN c.fecha_fin < CURDATE() THEN 3
                    ELSE 2
                END,
                c.fecha_inicio DESC
            LIMIT :limit OFFSET :offset";

    $stmt = $pdo->prepare($sql);
    $stmt->bindParam(':limit', $itemsPorPagina, PDO::PARAM_INT);
    $stmt->bindParam(':offset', $offset, PDO::PARAM_INT);
    $stmt->execute();
    $cursos = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Procesar acciones POST
    if ($_SERVER['REQUEST_METHOD'] === 'POST') {
        // Validar token CSRF
        if (!isset($_POST['csrf_token']) || !hash_equals($_SESSION['csrf_token'], $_POST['csrf_token'])) {
            throw new Exception("Token de seguridad inválido");
        }

        // Eliminar curso
        if (isset($_POST['delete_id'])) {
            $curso_id = (int)$_POST['delete_id'];
            
            $pdo->beginTransaction();
            try {
                // Eliminar inscripciones primero
                $stmt = $pdo->prepare("DELETE FROM inscripciones WHERE curso_id = ?");
                $stmt->execute([$curso_id]);
                
                // Luego eliminar el curso
                $stmt = $pdo->prepare("DELETE FROM cursos WHERE id = ?");
                $stmt->execute([$curso_id]);
                
                $pdo->commit();
                
                $_SESSION['flash_message'] = [
                    'type' => 'success',
                    'message' => 'Curso eliminado correctamente'
                ];
                
                ob_end_clean();
                header("Location: ver_cursos.php");
                exit;
                
            } catch (PDOException $e) {
                $pdo->rollBack();
                throw new Exception("Error al eliminar curso: " . $e->getMessage());
            }
        }

        // Habilitar/Deshabilitar curso
        if (isset($_POST['toggle_habilitacion'])) {
            $curso_id = (int)$_POST['curso_id'];
            $accion = $_POST['accion'];
            
            $habilitado = ($accion === 'habilitar') ? 1 : 0;
            
            $stmt = $pdo->prepare("UPDATE cursos SET habilitado = ? WHERE id = ?");
            $stmt->execute([$habilitado, $curso_id]);
            
            $_SESSION['flash_message'] = [
                'type' => 'success',
                'message' => 'Curso ' . ($habilitado ? 'habilitado' : 'deshabilitado') . ' correctamente'
            ];
            
            ob_end_clean();
            header("Location: ver_cursos.php");
            exit;
        }
    }

} catch (Exception $e) {
    ob_end_clean();
    $_SESSION['flash_message'] = [
        'type' => 'danger',
        'message' => 'Error: ' . $e->getMessage()
    ];
    header("Location: ver_cursos.php");
    exit;
}

// Limpiar buffer y mostrar HTML
ob_end_flush();
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Gestión de Cursos | ESIBOC</title>
    
    <!-- Google Font: Source Sans Pro -->
    <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,400i,700&display=fallback">
    <!-- Font Awesome -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- Theme style -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/css/adminlte.min.css">
    <!-- Custom CSS -->
    <style>
        /* Estilos para la tabla y columnas */
        .table {
            table-layout: fixed;
            width: 100%;
            margin-bottom: 1rem;
            background-color: transparent;
            border-collapse: collapse;
        }

        .table th, .table td {
            vertical-align: middle;
            padding: 12px 8px;
            line-height: 1.5;
            border-top: 1px solid #dee2e6;
        }

        /* Anchos específicos para cada columna */
        .table th:nth-child(1), .table td:nth-child(1) { width: 20%; } /* Nombre */
        .table th:nth-child(2), .table td:nth-child(2) { width: 10%; } /* Registro */
        .table th:nth-child(3), .table td:nth-child(3) { width: 15%; } /* Fechas */
        .table th:nth-child(4), .table td:nth-child(4) { width: 8%; } /* Inscritos */
        .table th:nth-child(5), .table td:nth-child(5) { width: 15%; } /* Cupos */
        .table th:nth-child(6), .table td:nth-child(6) { width: 15%; } /* Estado */
        .table th:nth-child(7), .table td:nth-child(7) { width: 17%; } /* Acciones */

        /* Ajustes para contenido largo */
        .table td {
            word-wrap: break-word;
            white-space: normal !important;
        }

        /* Cabecera de tabla oscura */
        .thead-dark th {
            color: #fff;
            background-color: #343a40;
            border-color: #454d55;
        }

        /* Tabla hover */
        .table-hover tbody tr:hover {
            background-color: rgba(0, 0, 0, 0.075);
        }

        /* Centrado de texto */
        .text-center {
            text-align: center !important;
        }

        /* Barra de progreso */
        .progress {
            height: 8px;
            margin-top: 5px;
            background-color: #e9ecef;
            border-radius: 0.25rem;
        }

        .progress-bar {
            transition: width 0.6s ease;
            height: 100%;
            border-radius: 0.25rem;
        }

        /* Badges de estado */
        .badge-custom {
            font-size: 0.85rem;
            font-weight: 600;
            padding: 5px 10px;
            display: inline-flex;
            align-items: center;
            justify-content: center;
            min-width: 80px;
            border-radius: 0.25rem;
        }

        .badge-disponible { background-color: #d4edda; color: #28a745; }
        .badge-lleno { background-color: #f8d7da; color: #dc3545; }
        .badge-proximo { background-color: #d1ecf1; color: #17a2b8; }
        .badge-finalizado { background-color: #fff3cd; color: #d39e00; }
        .badge-secondary { background-color: rgb(185, 8, 8); color: rgb(255, 255, 255); }

        /* Botones de acción */
        .action-btns {
            display: flex;
            justify-content: center;
            gap: 5px;
            flex-wrap: wrap;
        }

        .action-btns .btn {
            padding: 0.375rem 0.5rem;
            font-size: 0.875rem;
        }

        /* Responsive */
        @media (max-width: 768px) {
            .table-responsive {
                display: block;
                width: 100%;
                overflow-x: auto;
                -webkit-overflow-scrolling: touch;
            }
            
            .table {
                width: auto;
                min-width: 100%;
            }
            
            .table th, .table td {
                white-space: nowrap;
            }
            
            .action-btns {
                flex-direction: column;
                align-items: center;
            }
        }
        
        /* Estilos para el menú fijo y scroll */
        .main-sidebar {
            position: fixed;
            height: 100vh;
            overflow-y: auto;
        }
        
        .content-wrapper {
            margin-left: 250px;
            overflow-y: auto;
            height: 100vh;
        }
        
        .main-header {
            position: fixed;
            width: 100%;
            z-index: 1030;
            left: 0;
        }
        
        .content {
            padding-top: 70px;
            padding-bottom: 60px;
        }
        
        .main-footer {
            position: fixed;
            bottom: 0;
            width: 100%;
            margin-left: 250px;
            z-index: 1000;
            background: #fff;
        }
        
        .pagination-container {
            display: flex;
            justify-content: center;
            margin-top: 20px;
        }
        
        /* Barra de desplazamiento personalizada */
        ::-webkit-scrollbar {
            width: 8px;
            height: 8px;
        }
        ::-webkit-scrollbar-track {
            background: #f1f1f1;
        }
        ::-webkit-scrollbar-thumb {
            background: #888;
            border-radius: 4px;
        }
        ::-webkit-scrollbar-thumb:hover {
            background: #555;
        }
        
        /* Ajustes para dispositivos móviles */
        @media (max-width: 991px) {
            .main-sidebar {
                margin-left: -250px;
            }
            .content-wrapper {
                margin-left: 0;
            }
            .main-footer {
                margin-left: 0;
            }
            .main-sidebar.sidebar-open {
                margin-left: 0;
            }
            .content-wrapper.sidebar-open {
                margin-left: 250px;
            }
        }
    </style>
</head>
<body class="hold-transition sidebar-mini">
<div class="wrapper">

    <!-- Navbar -->
    <nav class="main-header navbar navbar-expand navbar-white navbar-light">
        <!-- Left navbar links -->
        <ul class="navbar-nav">
            <li class="nav-item">
                <a class="nav-link" data-widget="pushmenu" href="#" role="button"><i class="fas fa-bars"></i></a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="dashboard.php" class="nav-link">Inicio</a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="ver_cursos.php" class="nav-link active">Cursos</a>
            </li>
        </ul>
    </nav>
    <!-- /.navbar -->

    <!-- Main Sidebar Container -->
    <aside class="main-sidebar sidebar-dark-primary elevation-4">
        <!-- Brand Logo -->
        <a href="dashboard.php" class="brand-link">
            <span class="brand-text font-weight-light">ESIBOC Admin</span>
        </a>

        <!-- Sidebar -->
        <div class="sidebar">
            <!-- Sidebar user panel (optional) -->
            <div class="user-panel mt-3 pb-3 mb-3 d-flex">
                <div class="image">
                    <span class="img-circle elevation-2 bg-info d-flex align-items-center justify-content-center" 
                          style="width: 40px; height: 40px; font-weight: bold; font-size: 18px;">
                        <?= strtoupper(substr($_SESSION['admin_nombre'], 0, 1)) ?>
                    </span>
                </div>
                <div class="info">
                    <a href="#" class="d-block"><?= htmlspecialchars($_SESSION['admin_nombre']) ?></a>
                </div>
            </div>

            <!-- Sidebar Menu -->
            <nav class="mt-2">
                <ul class="nav nav-pills nav-sidebar flex-column" data-widget="treeview" role="menu" data-accordion="false">
                    <li class="nav-item">
                        <a href="dashboard.php" class="nav-link">
                            <i class="nav-icon fas fa-tachometer-alt"></i>
                            <p>Dashboard</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="crear_curso.php" class="nav-link">
                            <i class="nav-icon fas fa-plus-circle"></i>
                            <p>Crear Curso</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="ver_cursos.php" class="nav-link active">
                            <i class="nav-icon fas fa-book"></i>
                            <p>Gestionar Cursos</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="inscribir_participante.php" class="nav-link">
                            <i class="nav-icon fas fa-user-plus"></i>
                            <p>Inscribir Participante</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="ver_inscritos.php" class="nav-link">
                            <i class="nav-icon fas fa-clipboard-list"></i>
                            <p>Ver Inscripciones</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="logout.php" class="nav-link text-danger">
                            <i class="nav-icon fas fa-sign-out-alt"></i>
                            <p>Cerrar Sesión</p>
                        </a>
                    </li>
                </ul>
            </nav>
            <!-- /.sidebar-menu -->
        </div>
        <!-- /.sidebar -->
    </aside>

    <!-- Content Wrapper. Contains page content -->
    <div class="content-wrapper">
        <!-- Content Header (Page header) -->
        <section class="content-header">
            <div class="container-fluid">
                <div class="row mb-2">
                    <div class="col-sm-6">
                        <h1>Gestión de Cursos</h1>
                    </div>
                    <div class="col-sm-6">
                        <ol class="breadcrumb float-sm-right">
                            <li class="breadcrumb-item"><a href="dashboard.php">Inicio</a></li>
                            <li class="breadcrumb-item active">Cursos</li>
                        </ol>
                    </div>
                </div>
            </div><!-- /.container-fluid -->
        </section>

        <!-- Main content -->
        <section class="content">
            <div class="container-fluid">
                <div class="row">
                    <div class="col-12">
                        <div class="card">
                            <div class="card-header">
                                <h3 class="card-title">Listado de cursos</h3>
                                <div class="card-tools">
                                    <a href="crear_curso.php" class="btn btn-primary btn-sm">
                                        <i class="fas fa-plus-circle"></i> Nuevo Curso
                                    </a>
                                </div>
                            </div>
                            <!-- /.card-header -->
                            
                            <!-- Mostrar mensajes flash -->
                            <?php if (isset($_SESSION['flash_message'])): ?>
                                <div class="alert alert-<?= $_SESSION['flash_message']['type'] ?> alert-dismissible m-3">
                                    <button type="button" class="close" data-dismiss="alert" aria-hidden="true">×</button>
                                    <h5><i class="icon fas <?= $_SESSION['flash_message']['type'] === 'success' ? 'fa-check' : 'fa-ban' ?>"></i> 
                                        <?= $_SESSION['flash_message']['type'] === 'success' ? 'Éxito!' : 'Error!' ?>
                                    </h5>
                                    <?= $_SESSION['flash_message']['message'] ?>
                                </div>
                                <?php unset($_SESSION['flash_message']); ?>
                            <?php endif; ?>

                            <div class="card-body">
                                <div class="table-responsive">
                                    <table class="table table-bordered table-hover">
                                        <thead class="thead-dark">
                                            <tr>
                                                <th>Nombre</th>
                                                <th>Registro</th>
                                                <th>Fechas</th>
                                                <th class="text-center">Inscritos</th>
                                                <th>Cupos</th>
                                                <th class="text-center">Estado</th>
                                                <th class="text-center">Acciones</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <?php if (empty($cursos)): ?>
                                                <tr>
                                                    <td colspan="7" class="text-center">No hay cursos registrados</td>
                                                </tr>
                                            <?php else: ?>
                                                <?php foreach ($cursos as $curso): ?>
                                                    <tr>
                                                        <td class="align-middle">
                                                            <strong><?= htmlspecialchars($curso['nombre']) ?></strong>
                                                        </td>
                                                        <td class="align-middle"><?= htmlspecialchars($curso['numero_registro']) ?></td>
                                                        <td class="align-middle">
                                                            <div><strong>Inicio:</strong> <?= date('d/m/Y', strtotime($curso['fecha_inicio'])) ?></div>
                                                            <div><strong>Fin:</strong> <?= date('d/m/Y', strtotime($curso['fecha_fin'])) ?></div>
                                                        </td>
                                                        <td class="align-middle text-center"><?= $curso['inscritos'] ?></td>
                                                        <td class="align-middle">
                                                            <?= $curso['inscritos'] ?> / <?= $curso['cupo_maximo'] ?>
                                                            <div class="progress">
                                                                <div class="progress-bar bg-<?= ($curso['inscritos']/$curso['cupo_maximo'] > 0.8) ? 'danger' : 'success' ?>" 
                                                                     role="progressbar" 
                                                                     style="width: <?= min(100, ($curso['inscritos']/$curso['cupo_maximo'])*100) ?>%" 
                                                                     aria-valuenow="<?= $curso['inscritos'] ?>" 
                                                                     aria-valuemin="0" 
                                                                     aria-valuemax="<?= $curso['cupo_maximo'] ?>">
                                                                </div>
                                                            </div>
                                                            <small class="text-muted">Disponibles: <?= $curso['cupos_disponibles'] ?></small>
                                                        </td>
                                                        <td class="align-middle text-center">
                                                            <?php
                                                            $badge_class = '';
                                                            $estado_text = $curso['estado'];
                                                            
                                                            switch ($curso['estado']) {
                                                                case 'DISPONIBLE':
                                                                    $badge_class = 'badge-disponible';
                                                                    if ($curso['cupos_disponibles'] <= ($curso['cupo_maximo'] * 0.2)) {
                                                                        $estado_text .= ' (ÚLTIMOS)';
                                                                    }
                                                                    break;
                                                                case 'CUPO LLENO':
                                                                    $badge_class = 'badge-lleno';
                                                                    break;
                                                                case 'PRÓXIMO':
                                                                    $badge_class = 'badge-proximo';
                                                                    break;
                                                                case 'FINALIZADO':
                                                                    $badge_class = 'badge-finalizado';
                                                                    break;
                                                            }
                                                            ?>
                                                            <span class="badge badge-custom <?= $badge_class ?>">
                                                                <?= $estado_text ?>
                                                            </span>
                                                            <?php if (!$curso['habilitado']): ?>
                                                                <br>
                                                                <span class="badge badge-custom badge-secondary mt-1">
                                                                    <i class="fas fa-ban"></i> DESHABILITADO
                                                                </span>
                                                            <?php endif; ?>
                                                        </td>
                                                        <td class="align-middle text-center">
                                                            <div class="action-btns">
                                                                <a href="editar_curso.php?id=<?= $curso['id'] ?>" class="btn btn-sm btn-warning" title="Editar">
                                                                    <i class="fas fa-pen"></i>
                                                                </a>
                                                                <a href="ver_inscritos.php?curso_id=<?= $curso['id'] ?>" class="btn btn-sm btn-info" title="Ver Participantes">
                                                                    <i class="fas fa-users"></i>
                                                                </a>
                                                                
                                                                <!-- Botón de descarga - Corregido para mostrar solo si hay inscritos -->
                                                                <?php if ($curso['inscritos'] > 0): ?>
                                                                    <?php 
                                                                    $nombreCarpeta = preg_replace('/[^A-Za-z0-9\-]/', '', str_replace(' ', '_', $curso['nombre'])) . '_' . $curso['numero_registro'];
                                                                    $rutaCarpetaCurso = '../cursos/' . $nombreCarpeta;
                                                                    $tieneContenido = file_exists($rutaCarpetaCurso) && count(glob($rutaCarpetaCurso . "/*")) > 0;
                                                                    ?>
                                                                    <?php if ($tieneContenido): ?>
                                                                        <a href="descargar_curso.php?curso_id=<?= $curso['id'] ?>" class="btn btn-sm btn-primary" title="Descargar Carpeta">
                                                                            <i class="fas fa-download"></i>
                                                                        </a>
                                                                    <?php else: ?>
                                                                        <button class="btn btn-sm btn-secondary" title="No hay archivos para descargar" disabled>
                                                                            <i class="fas fa-cloud-download-alt"></i>
                                                                        </button>
                                                                    <?php endif; ?>
                                                                <?php else: ?>
                                                                    <button class="btn btn-sm btn-secondary" title="No hay participantes inscritos" disabled>
                                                                        <i class="fas fa-cloud-download-alt"></i>
                                                                    </button>
                                                                <?php endif; ?>
                                                                
                                                                <?php if ($curso['habilitado']): ?>
                                                                    <form method="POST" style="display: inline;">
                                                                        <input type="hidden" name="curso_id" value="<?= $curso['id'] ?>">
                                                                        <input type="hidden" name="accion" value="deshabilitar">
                                                                        <input type="hidden" name="csrf_token" value="<?= $_SESSION['csrf_token'] ?>">
                                                                        <button type="submit" name="toggle_habilitacion" class="btn btn-sm btn-secondary" title="Deshabilitar">
                                                                            <i class="fas fa-toggle-on"></i>
                                                                        </button>
                                                                    </form>
                                                                <?php else: ?>
                                                                    <form method="POST" style="display: inline;">
                                                                        <input type="hidden" name="curso_id" value="<?= $curso['id'] ?>">
                                                                        <input type="hidden" name="accion" value="habilitar">
                                                                        <input type="hidden" name="csrf_token" value="<?= $_SESSION['csrf_token'] ?>">
                                                                        <button type="submit" name="toggle_habilitacion" class="btn btn-sm btn-success" title="Habilitar">
                                                                            <i class="fas fa-toggle-off"></i>
                                                                        </button>
                                                                    </form>
                                                                <?php endif; ?>
                                                                <form method="POST" style="display: inline;">
                                                                    <input type="hidden" name="delete_id" value="<?= $curso['id'] ?>">
                                                                    <input type="hidden" name="csrf_token" value="<?= $_SESSION['csrf_token'] ?>">
                                                                    <button type="submit" class="btn btn-sm btn-danger" title="Eliminar" 
                                                                        onclick="return confirm('¿Estás seguro de eliminar este curso?\nSe borrarán <?= $curso['inscritos'] ?> inscripciones relacionadas.')">
                                                                        <i class="fas fa-trash"></i>
                                                                    </button>
                                                                </form>
                                                            </div>
                                                        </td>
                                                    </tr>
                                                <?php endforeach; ?>
                                            <?php endif; ?>
                                        </tbody>
                                    </table>
                                </div>
                            </div>
                            <!-- /.card-body -->
                            
                            <!-- Paginación -->
                            <div class="card-footer clearfix">
                                <div class="pagination-container">
                                    <ul class="pagination pagination-sm m-0 float-right">
                                        <?php if ($paginaActual > 1): ?>
                                            <li class="page-item"><a class="page-link" href="?pagina=<?= $paginaActual - 1 ?>">&laquo;</a></li>
                                        <?php endif; ?>
                                        
                                        <?php 
                                        // Mostrar hasta 5 páginas alrededor de la actual
                                        $inicio = max(1, $paginaActual - 2);
                                        $fin = min($totalPaginas, $paginaActual + 2);
                                        
                                        for ($i = $inicio; $i <= $fin; $i++): ?>
                                            <li class="page-item <?= $i == $paginaActual ? 'active' : '' ?>">
                                                <a class="page-link" href="?pagina=<?= $i ?>"><?= $i ?></a>
                                            </li>
                                        <?php endfor; ?>
                                        
                                        <?php if ($paginaActual < $totalPaginas): ?>
                                            <li class="page-item"><a class="page-link" href="?pagina=<?= $paginaActual + 1 ?>">&raquo;</a></li>
                                        <?php endif; ?>
                                    </ul>
                                    <div class="float-right mr-3 mt-1">
                                        <small class="text-muted">Mostrando <?= count($cursos) ?> de <?= $totalCursos ?> cursos</small>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <!-- /.card -->
                    </div>
                    <!-- /.col -->
                </div>
                <!-- /.row -->
            </div><!-- /.container-fluid -->
        </section>
        <!-- /.content -->
    </div>
    <!-- /.content-wrapper -->

    <!-- Main Footer -->
    <footer class="main-footer">
        <strong>Copyright &copy; <?= date('Y') ?> <a href="#">ESIBOC</a>.</strong>
        Todos los derechos reservados.
        <div class="float-right d-none d-sm-inline-block">
            <b>Versión</b> 1.0.0
        </div>
    </footer>
</div>
<!-- ./wrapper -->

<!-- REQUIRED SCRIPTS -->
<!-- jQuery -->
<script src="https://cdn.jsdelivr.net/npm/jquery@3.6.0/dist/jquery.min.js"></script>
<!-- Bootstrap 4 -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/js/bootstrap.bundle.min.js"></script>
<!-- AdminLTE App -->
<script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>
<!-- Custom scripts -->
<script>
$(function () {
    // Ajustar altura del contenido cuando se redimensiona la ventana
    function adjustContentHeight() {
        var windowHeight = $(window).height();
        var headerHeight = $('.main-header').outerHeight();
        var footerHeight = $('.main-footer').outerHeight();
        
        $('.content-wrapper').css({
            'height': windowHeight + 'px',
            'padding-bottom': footerHeight + 'px'
        });
        
        $('.content').css('min-height', windowHeight - headerHeight - footerHeight + 'px');
    }
    
    // Ejecutar al cargar y al redimensionar
    adjustContentHeight();
    $(window).resize(adjustContentHeight);
    
    // Mejora de confirmación para eliminar
    $('form[method="POST"]').on('submit', function(e) {
        if ($(this).find('button[type="submit"][name="delete_id"]').length > 0) {
            if (!confirm('¿Confirmas que deseas eliminar este curso?\nEsta acción no se puede deshacer.')) {
                e.preventDefault();
            }
        }
    });
    
    // Mantener el menú desplegado al recargar
    $('.nav-sidebar').find('li').has('ul').each(function() {
        $(this).addClass('menu-open');
    });
    
    // Manejar el menú en dispositivos móviles
    $('[data-widget="pushmenu"]').on('click', function() {
        $('.main-sidebar').toggleClass('sidebar-open');
        $('.content-wrapper').toggleClass('sidebar-open');
       });
});
</script>
</body>
</html>