<?php
// Iniciar buffer de salida al principio
ob_start();

// Configuración de errores (solo para desarrollo)
error_reporting(E_ALL);
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);

// Aumentar límites para hosting compartido
ini_set('memory_limit', '256M');
set_time_limit(300); // 5 minutos

// Inicio seguro de sesión
if (session_status() !== PHP_SESSION_ACTIVE) {
    session_start();
}

// Verificación de autenticación
if (!isset($_SESSION['admin_id'])) {
    header("Location: login.php");
    ob_end_flush();
    exit;
}

// Conexión a base de datos
require_once '../config/database.php';

// Validar y obtener el ID del curso
if (!isset($_GET['curso_id']) || !is_numeric($_GET['curso_id'])) {
    $_SESSION['flash_message'] = [
        'type' => 'danger',
        'message' => 'ID de curso inválido.'
    ];
    header("Location: ver_cursos.php");
    ob_end_flush();
    exit;
}

$curso_id = (int)$_GET['curso_id'];

// Función mejorada para obtener la ruta de la foto
function getFotoParticipante($participante, $curso_nombre, $curso_numero) {
    if (empty($participante['archivo_img_fotografia'])) {
        return false;
    }
    
    if (filter_var($participante['archivo_img_fotografia'], FILTER_VALIDATE_URL)) {
        return $participante['archivo_img_fotografia'];
    }
    
    $base_path = '../cursos/';
    $curso_folder = preg_replace('/[^A-Za-z0-9\-]/', '', str_replace(' ', '_', $curso_nombre)) . '_' . $curso_numero;
    $participante_folder = preg_replace('/[^A-Za-z0-9\-]/', '', str_replace(' ', '_', $participante['nombres'] . '_' . $participante['apellidos'])) . '_' . $participante['cedula'];
    
    $rutas_posibles = [
        $base_path . $curso_folder . '/' . $participante_folder . '/' . $participante['archivo_img_fotografia'],
        $base_path . $curso_folder . '/' . $participante['archivo_img_fotografia'],
        '../' . $participante['archivo_img_fotografia']
    ];
    
    foreach ($rutas_posibles as $ruta) {
        if (file_exists($ruta) && is_readable($ruta)) {
            return $ruta;
        }
    }
    
    return false;
}


// Función para generar CSV de matrícula con nombres en mayúsculas y soporte para caracteres especiales
function generarCSVMatricula($participantes, $curso_id) {
    // Limpiar buffers antes de enviar
    while (ob_get_level()) {
        ob_end_clean();
    }

    // Configurar headers para descarga con UTF-8
    header('Content-Type: text/csv; charset=utf-8');
    header('Content-Disposition: attachment; filename="matricula_curso_' . $curso_id . '.csv"');
    header('Pragma: no-cache');
    header('Expires: 0');
    
    // Abrir el flujo de salida
    $output = fopen('php://output', 'w');
    
    // Escribir BOM manualmente para UTF-8
    fwrite($output, "\xEF\xBB\xBF");
    
    // Encabezados del CSV
    fputcsv($output, ['username', 'password', 'firstname', 'lastname', 'email']);
    
    foreach ($participantes as $p) {
        // Preparar datos con nombres en mayúsculas y soporte para caracteres especiales
        $row = [
            $p['cedula'], // username
            $p['cedula'], // password
            mb_strtoupper($p['nombres'], 'UTF-8'), // firstname en mayúsculas
            mb_strtoupper($p['apellidos'], 'UTF-8'), // lastname en mayúsculas
            mb_strtolower($p['correo'], 'UTF-8') // email en minúsculas
        ];
        
        // Escribir fila en CSV
        fputcsv($output, $row);
    }
    
    // Cerrar el flujo de salida
    fclose($output);
    exit;
}


try {
    // Obtener información del curso
    $stmtCurso = $pdo->prepare("SELECT nombre, numero_registro FROM cursos WHERE id = ?");
    $stmtCurso->execute([$curso_id]);
    $curso = $stmtCurso->fetch(PDO::FETCH_ASSOC);

    if (!$curso) {
        $_SESSION['flash_message'] = [
            'type' => 'danger',
            'message' => 'Curso no encontrado.'
        ];
        header("Location: ver_cursos.php");
        ob_end_flush();
        exit;
    }

    // Obtener participantes inscritos ORDENADOS alfabéticamente
    $stmt = $pdo->prepare("
        SELECT p.*, i.fecha_inscripcion
        FROM participantes p
        INNER JOIN inscripciones i ON p.id = i.participante_id
        WHERE i.curso_id = ?
        ORDER BY p.nombres ASC, p.apellidos ASC
    ");
    $stmt->execute([$curso_id]);
    $participantes = $stmt->fetchAll(PDO::FETCH_ASSOC);

    // Obtener datos para el gráfico (participación por municipio)
    $stmtChart = $pdo->prepare("
        SELECT p.municipio, COUNT(*) as conteo
        FROM participantes p
        INNER JOIN inscripciones i ON p.id = i.participante_id
        WHERE i.curso_id = ?
        GROUP BY p.municipio
        ORDER BY conteo DESC
    ");
    $stmtChart->execute([$curso_id]);
    $chartData = $stmtChart->fetchAll(PDO::FETCH_ASSOC);

    // Preparar datos para el gráfico
    $municipios = [];
    $conteos = [];
    $totalParticipantes = 0;
    
    foreach ($chartData as $row) {
        $municipios[] = $row['municipio'];
        $conteos[] = $row['conteo'];
        $totalParticipantes += $row['conteo'];
    }
    
    // Calcular porcentajes
    $porcentajes = [];
    foreach ($conteos as $conteo) {
        $porcentajes[] = $totalParticipantes > 0 ? round(($conteo / $totalParticipantes) * 100, 2) : 0;
    }
    
    // Generar colores aleatorios para el gráfico
    $colores = [];
    foreach ($municipios as $i) {
        $colores[] = sprintf('#%06X', mt_rand(0, 0xFFFFFF));
    }

} catch (Exception $e) {
    $_SESSION['flash_message'] = [
        'type' => 'danger',
        'message' => 'Error al obtener los participantes: ' . $e->getMessage()
    ];
    header("Location: ver_cursos.php");
    ob_end_flush();
    exit;
}

// Procesar descarga de matrícula
if (isset($_GET['descargar_matricula']) && $_GET['descargar_matricula'] == '1') {
    generarCSVMatricula($participantes, $curso_id);
}


// Procesar descarga de archivos
if (isset($_GET['descargar_excel']) && $_GET['descargar_excel'] == '1') {
    // Determinar el formato solicitado
    $formato = isset($_GET['formato']) && $_GET['formato'] == 'csv' ? 'csv' : 'zip';
    
    try {
        // Verificar si podemos usar ZIP (solo si no se solicitó CSV explícitamente)
        $usarZip = ($formato == 'zip') && class_exists('ZipArchive');
        
        // Directorio temporal
        $tempDir = sys_get_temp_dir() . '/esiboc_' . uniqid();
        if (!mkdir($tempDir, 0755, true)) {
            throw new Exception("No se pudo crear directorio temporal");
        }

        // Función para asegurar encoding UTF-8
        function toUtf8($string) {
            if (!mb_detect_encoding($string, 'UTF-8', true)) {
                return utf8_encode($string);
            }
            return $string;
        }

        // 1. Crear archivo de datos (CSV como respaldo)
        $csvPath = $tempDir . '/participantes.csv';
        $csvFile = fopen($csvPath, 'w');
        
        // Añadir BOM para UTF-8
        fwrite($csvFile, "\xEF\xBB\xBF");
        
        // Encabezados CSV actualizados con dirección
        fputcsv($csvFile, array_map('toUtf8', [
            'Nombre Completo', 
            'Cédula', 
            'Celular', 
            'Correo',
            'Dirección de Correspondencia',
            'Departamento',
            'Cuerpo de Bomberos',
            'Fecha Inscripción',
            'Ruta Foto'
        ]));
        
        // Datos CSV y preparación para Excel si está disponible
        $datosParaExcel = [];
        foreach ($participantes as $p) {
            $foto_path = getFotoParticipante($p, $curso['nombre'], $curso['numero_registro']);
            $foto_nombre = '';
            
            if ($foto_path && file_exists($foto_path)) {
                $ext = pathinfo($foto_path, PATHINFO_EXTENSION);
                $foto_nombre = $p['cedula'] . '_' . preg_replace('/[^A-Za-z0-9\-]/', '_', $p['nombres']) . '.' . ($ext ?: 'jpg');
            }
            
            // Escribir en CSV con dirección
            fputcsv($csvFile, array_map('toUtf8', [
               mb_strtoupper($p['nombres'] . ' ' . $p['apellidos']),  // Cambiado a mb_strtoupper
                $p['cedula'],
                $p['celular'],
                strtolower($p['correo']),  // Convertir a minúscula aquí
                $p['direccion'] ?? 'No especificada',
                $p['departamento'],
                'CB ' . mb_strtoupper($p['clase_cuerpo_bomberos']) . ' ' . mb_strtoupper($p['municipio']),
                date('d/m/Y', strtotime($p['fecha_inscripcion'])),
                $foto_path ? 'fotos/'.$foto_nombre : 'Sin foto'
            ]));
            
            // Preparar datos para Excel si está disponible
            $datosParaExcel[] = [
                'nombre' => $p['nombres'] . ' ' . $p['apellidos'],
                'cedula' => $p['cedula'],
                'celular' => $p['celular'],
                'correo' => $p['correo'],
                'direccion' => $p['direccion'] ?? 'No especificada',
                'departamento' => $p['departamento'],
                'municipio' => $p['municipio'],
                'fecha' => date('d/m/Y', strtotime($p['fecha_inscripcion'])),
                'foto_path' => $foto_path,
                'foto_nombre' => $foto_nombre
            ];
        }
        fclose($csvFile);

        // 2. Procesar fotos
        $fotosDir = $tempDir . '/fotos';
        if (!mkdir($fotosDir, 0755, true)) {
            throw new Exception("No se pudo crear directorio de fotos");
        }

        foreach ($datosParaExcel as $participante) {
            if ($participante['foto_path'] && file_exists($participante['foto_path'])) {
                try {
                    copy($participante['foto_path'], $fotosDir . '/' . $participante['foto_nombre']);
                } catch (Exception $e) {
                    error_log("Error al copiar foto: " . $e->getMessage());
                }
            }
        }

        // 3. Crear archivo con datos del gráfico (HTML)
        $chartHtmlPath = $tempDir . '/grafico_participacion.html';
        $chartHtml = '<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Participación por Municipio - ' . htmlspecialchars($curso['nombre']) . '</title>
    <style>
        body { font-family: Arial, sans-serif; margin: 20px; }
        h1 { color: #333; }
        .chart-container { width: 800px; height: 600px; margin: 20px auto; }
        table { width: 100%; border-collapse: collapse; margin-top: 20px; }
        th, td { border: 1px solid #ddd; padding: 8px; text-align: left; }
        th { background-color: #f2f2f2; }
    </style>
</head>
<body>
    <h1>Participación por Municipio - ' . htmlspecialchars($curso['nombre']) . '</h1>
    <p>Total de participantes: ' . $totalParticipantes . '</p>
    
    <div class="chart-container">
        <!-- El gráfico se generará con JavaScript -->
        <canvas id="participationChart"></canvas>
    </div>
    
    <h2>Detalle de Participación</h2>
    <table>
        <thead>
            <tr>
                <th>Municipio</th>
                <th>Participantes</th>
                <th>Porcentaje</th>
            </tr>
        </thead>
        <tbody>';
        
        for ($i = 0; $i < count($municipios); $i++) {
            $chartHtml .= '
            <tr>
                <td>' . htmlspecialchars($municipios[$i]) . '</td>
                <td>' . $conteos[$i] . '</td>
                <td>' . $porcentajes[$i] . '%</td>
            </tr>';
        }
        
        $chartHtml .= '
        </tbody>
        <tfoot>
            <tr>
                <th>Total</th>
                <th>' . $totalParticipantes . '</th>
                <th>100%</th>
            </tr>
        </tfoot>
    </table>
    
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/chartjs-plugin-datalabels@2.0.0"></script>
    <script>
        var ctx = document.getElementById(\'participationChart\').getContext(\'2d\');
        var chart = new Chart(ctx, {
            type: \'pie\',
            data: {
                labels: ' . json_encode($municipios) . ',
                datasets: [{
                    data: ' . json_encode($conteos) . ',
                    backgroundColor: ' . json_encode($colores) . ',
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                plugins: {
                    legend: {
                        display: false
                    },
                    tooltip: {
                        callbacks: {
                            label: function(context) {
                                return context.label + \': \' + context.raw + \' (\' + ' . json_encode($porcentajes) . '[context.dataIndex] + \'%)\';
                            }
                        }
                    },
                    datalabels: {
                        display: true,
                        color: \'#fff\',
                        font: {
                            weight: \'bold\',
                            size: 12
                        },
                        formatter: function(value, context) {
    return `${data.municipios[context.dataIndex]}: ${data.porcentajes[context.dataIndex]}%`;
}

                        },
                        textShadowBlur: 10,
                        textShadowColor: \'black\'
                    }
                }
            },
            plugins: [ChartDataLabels]
        });
    </script>
</body>
</html>';
        
        file_put_contents($chartHtmlPath, $chartHtml);

        // 4. Intentar crear Excel si PhpSpreadsheet está disponible y no se solicitó CSV
        $excelPath = '';
        if ($formato != 'csv' && class_exists('\PhpOffice\PhpSpreadsheet\Spreadsheet')) {
            try {
                $spreadsheet = new \PhpOffice\PhpSpreadsheet\Spreadsheet();
                $sheet = $spreadsheet->getActiveSheet();

                // Encabezados Excel actualizados
                $sheet->setCellValue('A1', 'Foto');
                $sheet->setCellValue('B1', 'Nombre Completo');
                $sheet->setCellValue('C1', 'Cédula');
                $sheet->setCellValue('D1', 'Celular');
                $sheet->setCellValue('E1', 'Correo');
                $sheet->setCellValue('F1', 'Dirección');
                $sheet->setCellValue('G1', 'Departamento');
                $sheet->setCellValue('H1', 'Institución');
                $sheet->setCellValue('I1', 'Fecha Inscripción');

                // Datos Excel
                $row = 2;
                foreach ($datosParaExcel as $p) {
                    $sheet->setCellValue('A' . $row, $p['foto_nombre'] ? 'fotos/'.$p['foto_nombre'] : 'Sin foto');
                    $sheet->setCellValue('B' . $row, $p['nombre']);
                    $sheet->setCellValue('C' . $row, $p['cedula']);
                    $sheet->setCellValue('D' . $row, $p['celular']);
                    $sheet->setCellValue('E' . $row, $p['correo']);
                    $sheet->setCellValue('F' . $row, $p['direccion']);
                    $sheet->setCellValue('G' . $row, $p['departamento']);
                    $sheet->setCellValue('H' . $row, $p['municipio']);
                    $sheet->setCellValue('I' . $row, $p['fecha']);
                    $row++;
                }

                // Autoajustar columnas
                foreach (range('A', 'I') as $col) {
                    $sheet->getColumnDimension($col)->setAutoSize(true);
                }

                // Guardar Excel
                $excelPath = $tempDir . '/participantes.xlsx';
                $writer = \PhpOffice\PhpSpreadsheet\IOFactory::createWriter($spreadsheet, 'Xlsx');
                $writer->save($excelPath);
            } catch (Exception $e) {
                // Si falla Excel, continuamos con CSV
                error_log("Error al crear Excel: " . $e->getMessage());
                $excelPath = '';
            }
        }

        // 5. Crear ZIP si es posible, si no enviar CSV directamente
        if ($usarZip && ($excelPath || $formato == 'zip')) {
            $zipPath = $tempDir . '/participantes.zip';
            $zip = new ZipArchive();
            
            if ($zip->open($zipPath, ZipArchive::CREATE | ZipArchive::OVERWRITE) === true) {
                if ($excelPath) {
                    $zip->addFile($excelPath, 'participantes.xlsx');
                }
                $zip->addFile($csvPath, 'participantes.csv');
                $zip->addFile($chartHtmlPath, 'grafico_participacion.html');
                
                $fotos = glob($fotosDir . '/*');
                if (!empty($fotos)) {
                    $zip->addEmptyDir('fotos');
                    foreach ($fotos as $foto) {
                        $zip->addFile($foto, 'fotos/' . basename($foto));
                    }
                }
                
                if (!$zip->close()) {
                    throw new Exception("Error al cerrar archivo ZIP");
                }

                if (!file_exists($zipPath)) {
                    throw new Exception("El archivo ZIP no se creó correctamente");
                }

                // Limpiar buffers antes de enviar
                while (ob_get_level()) {
                    ob_end_clean();
                }

                // Enviar ZIP
                header('Content-Type: application/zip');
                header('Content-Disposition: attachment; filename="participantes_curso_' . $curso_id . '.zip"');
                header('Content-Length: ' . filesize($zipPath));
                header('Pragma: no-cache');
                header('Expires: 0');
                
                if (readfile($zipPath) === false) {
                    throw new Exception("Error al enviar el archivo ZIP");
                }
                
                // Limpieza
                array_map('unlink', glob($fotosDir . '/*'));
                rmdir($fotosDir);
                if ($excelPath && file_exists($excelPath)) {
                    unlink($excelPath);
                }
                unlink($csvPath);
                unlink($chartHtmlPath);
                rmdir($tempDir);
                exit;
            }
        }

        // Si se solicitó CSV explícitamente o no se pudo crear ZIP/Excel, enviar CSV directamente
        while (ob_get_level()) {
            ob_end_clean();
        }

        header('Content-Type: text/csv; charset=utf-8');
        header('Content-Disposition: attachment; filename="participantes_curso_' . $curso_id . '.csv"');
        header('Pragma: no-cache');
        header('Expires: 0');
        
        if (readfile($csvPath) === false) {
            throw new Exception("Error al enviar el archivo CSV");
        }
        
        // Limpieza
        array_map('unlink', glob($fotosDir . '/*'));
        rmdir($fotosDir);
        if ($excelPath && file_exists($excelPath)) {
            unlink($excelPath);
        }
        unlink($csvPath);
        unlink($chartHtmlPath);
        rmdir($tempDir);
        exit;

    } catch (Exception $e) {
        // Limpieza en caso de error
        if (isset($fotosDir) && is_dir($fotosDir)) {
            array_map('unlink', glob($fotosDir . '/*'));
            @rmdir($fotosDir);
        }
        if (isset($excelPath) && file_exists($excelPath)) {
            @unlink($excelPath);
        }
        if (isset($csvPath) && file_exists($csvPath)) {
            @unlink($csvPath);
        }
        if (isset($chartHtmlPath) && file_exists($chartHtmlPath)) {
            @unlink($chartHtmlPath);
        }
        if (isset($tempDir) && is_dir($tempDir)) {
            array_map('unlink', glob($tempDir . '/*'));
            @rmdir($tempDir);
        }
        
        $_SESSION['flash_message'] = [
            'type' => 'danger',
            'message' => 'Error al generar el archivo: ' . $e->getMessage()
        ];
        header("Location: ?curso_id=" . $curso_id);
        ob_end_flush();
        exit;
    }
}

// Procesar descarga solo del gráfico
if (isset($_GET['descargar_grafico'])) {
    try {
        // Determinar el formato solicitado
        $formato = $_GET['descargar_grafico'];
        
        // Limpiar buffers antes de enviar
        while (ob_get_level()) {
            ob_end_clean();
        }

        if ($formato == 'html') {
            // Generar HTML del gráfico
            $html = '<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Participación por Municipio - ' . htmlspecialchars($curso['nombre']) . '</title>
    <style>
        body { font-family: Arial, sans-serif; margin: 20px; }
        h1 { color: #333; }
        .chart-container { width: 800px; height: 600px; margin: 20px auto; }
        table { width: 100%; border-collapse: collapse; margin-top: 20px; }
        th, td { border: 1px solid #ddd; padding: 8px; text-align: left; }
        th { background-color: #f2f2f2; }
    </style>
</head>
<body>
    <h1>Participación por Municipio - ' . htmlspecialchars($curso['nombre']) . '</h1>
    <p>Total de participantes: ' . $totalParticipantes . '</p>
    
    <div class="chart-container">
        <canvas id="participationChart"></canvas>
    </div>
    
    <h2>Detalle de Participación</h2>
    <table>
        <thead>
            <tr>
                <th>Municipio</th>
                <th>Participantes</th>
                <th>Porcentaje</th>
            </tr>
        </thead>
        <tbody>';
        
            for ($i = 0; $i < count($municipios); $i++) {
                $html .= '
                <tr>
                    <td>' . htmlspecialchars($municipios[$i]) . '</td>
                    <td>' . $conteos[$i] . '</td>
                    <td>' . $porcentajes[$i] . '%</td>
                </tr>';
            }
            
            $html .= '
        </tbody>
        <tfoot>
            <tr>
                <th>Total</th>
                <th>' . $totalParticipantes . '</th>
                <th>100%</th>
            </tr>
        </tfoot>
    </table>
    
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/chartjs-plugin-datalabels@2.0.0"></script>
    <script>
        var ctx = document.getElementById(\'participationChart\').getContext(\'2d\');
        var chart = new Chart(ctx, {
            type: \'pie\',
            data: {
                labels: ' . json_encode($municipios) . ',
                datasets: [{
                    data: ' . json_encode($conteos) . ',
                    backgroundColor: ' . json_encode($colores) . ',
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                plugins: {
                    legend: {
                        display: false
                    },
                    tooltip: {
                        callbacks: {
                            label: function(context) {
                                return context.label + \': \' + context.raw + \' (\' + ' . json_encode($porcentajes) . '[context.dataIndex] + \'%)\';
                            }
                        }
                    },
                    datalabels: {
                        display: true,
                        color: \'#fff\',
                        font: {
                            weight: \'bold\',
                            size: function(context) {
                            var porcentaje = data.porcentajes[context.dataIndex];
                            return porcentaje < 10 ? 8 : 12;
                            }                        },
                        formatter: function(value, context) {
                            return ' . json_encode($porcentajes) . '[context.dataIndex] + \'%\';
                        },
                        textShadowBlur: 10,
                        textShadowColor: \'black\'
                    }
                }
            },
            plugins: [ChartDataLabels]
        });
    </script>
</body>
</html>';

            // Enviar como archivo HTML
            header('Content-Type: text/html');
            header('Content-Disposition: attachment; filename="grafico_participacion_' . $curso_id . '.html"');
            header('Pragma: no-cache');
            header('Expires: 0');
            
            echo $html;
            exit;

        } elseif ($formato == 'png') {
            // Generar imagen PNG del gráfico
            
            // Requiere la librería GD
            if (!extension_loaded('gd')) {
                throw new Exception("La extensión GD no está instalada para generar imágenes");
            }

            // Configuración de la imagen
            $width = 800;
            $height = 600;
            $image = imagecreatetruecolor($width, $height);
            
            // Colores
            $white = imagecolorallocate($image, 255, 255, 255);
            $black = imagecolorallocate($image, 0, 0, 0);
            $gray = imagecolorallocate($image, 200, 200, 200);
            
            // Fondo blanco
            imagefilledrectangle($image, 0, 0, $width, $height, $white);
            
            // Título
            $title = "Participación por Municipio - " . $curso['nombre'];
            $font = 5; // Tamaño de fuente interno (1-5)
            $titleWidth = imagefontwidth($font) * strlen($title);
            imagestring($image, $font, ($width - $titleWidth) / 2, 10, $title, $black);
            
            // Subtítulo
            $subtitle = "Total de participantes: " . $totalParticipantes;
            $subtitleWidth = imagefontwidth($font) * strlen($subtitle);
            imagestring($image, $font, ($width - $subtitleWidth) / 2, 30, $subtitle, $black);
            
            // Configuración del gráfico de torta
            $centerX = $width / 2;
            $centerY = $height / 2 + 30;
            $radius = 200;
            $startAngle = 0;
            
            // Dibujar el gráfico de torta
            foreach ($conteos as $index => $value) {
                // Calcular ángulo para este segmento
                $percentage = $value / $totalParticipantes;
                $endAngle = $startAngle + 360 * $percentage;
                
                // Obtener color para este segmento
                $color = hexdec(substr($colores[$index], 1)); // Eliminar # y convertir a decimal
                $r = ($color >> 16) & 0xFF;
                $g = ($color >> 8) & 0xFF;
                $b = $color & 0xFF;
                $segmentColor = imagecolorallocate($image, $r, $g, $b);
                
                // Dibujar segmento
                imagefilledarc($image, $centerX, $centerY, $radius * 2, $radius * 2, 
                               $startAngle, $endAngle, $segmentColor, IMG_ARC_PIE);
                
                // Dibujar borde del segmento
                imagefilledarc($image, $centerX, $centerY, $radius * 2, $radius * 2, 
                               $startAngle, $endAngle, $black, IMG_ARC_NOFILL | IMG_ARC_EDGED);
                
                // Calcular posición de la etiqueta
                $midAngle = ($startAngle + $endAngle) / 2;
                $labelRadius = $radius * 0.7;
                $x = $centerX + $labelRadius * cos(deg2rad($midAngle));
                $y = $centerY + $labelRadius * sin(deg2rad($midAngle));
                
                // Texto de la etiqueta
                $label = round($percentage * 100) . '%';
                $textWidth = imagefontwidth($font) * strlen($label);
                $textHeight = imagefontheight($font);
                
                // Posición ajustada para centrar el texto
                $textX = $x - $textWidth / 2;
                $textY = $y - $textHeight / 2;
                
                // Dibujar etiqueta
                imagestring($image, $font, $textX, $textY, $label, $black);
                
                $startAngle = $endAngle;
            }
            
            // Leyenda
            $legendX = 50;
            $legendY = $height - 150;
            $legendColorSize = 20;
            $legendTextOffset = 30;
            $legendLineHeight = 30;
            
            foreach ($municipios as $index => $municipio) {
                // Color de la leyenda
                $color = hexdec(substr($colores[$index], 1));
                $r = ($color >> 16) & 0xFF;
                $g = ($color >> 8) & 0xFF;
                $b = $color & 0xFF;
                $legendColor = imagecolorallocate($image, $r, $g, $b);
                
                // Cuadrado de color
                imagefilledrectangle($image, $legendX, $legendY, 
                                    $legendX + $legendColorSize, $legendY + $legendColorSize, 
                                    $legendColor);
                imagerectangle($image, $legendX, $legendY, 
                             $legendX + $legendColorSize, $legendY + $legendColorSize, 
                             $black);
                
                // Texto de la leyenda
                $legendText = $municipio . ' (' . $conteos[$index] . ')';
                imagestring($image, $font, $legendX + $legendTextOffset, $legendY + 5, $legendText, $black);
                
                $legendY += $legendLineHeight;
            }
            
            // Enviar como imagen PNG
            header('Content-Type: image/png');
            header('Content-Disposition: attachment; filename="grafico_participacion_' . $curso_id . '.png"');
            header('Pragma: no-cache');
            header('Expires: 0');
            
            imagepng($image);
            imagedestroy($image);
            exit;
        } else {
            throw new Exception("Formato de descarga no válido");
        }

    } catch (Exception $e) {
        $_SESSION['flash_message'] = [
            'type' => 'danger',
            'message' => 'Error al generar el gráfico: ' . $e->getMessage()
        ];
        header("Location: ?curso_id=" . $curso_id);
        ob_end_flush();
        exit;
    }
}

// Limpiar buffer antes de enviar HTML
ob_clean();
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Participantes del Curso | ESIBOC</title>
    
    <!-- Google Font: Source Sans Pro -->
    <link rel="stylesheet" href="https://fonts.googleapis.com/css?family=Source+Sans+Pro:300,400,400i,700&display=fallback">
    <!-- Font Awesome Icons -->
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css">
    <!-- IonIcons -->
    <link rel="stylesheet" href="https://code.ionicframework.com/ionicons/2.0.1/css/ionicons.min.css">
    <!-- Theme style -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/css/adminlte.min.css">
    <!-- DataTables -->
    <link rel="stylesheet" href="https://cdn.datatables.net/1.11.5/css/dataTables.bootstrap4.min.css">
    <!-- Chart.js -->
    <script src="https://cdn.jsdelivr.net/npm/chart.js"></script>
    <!-- Chart.js datalabels plugin -->
    <script src="https://cdn.jsdelivr.net/npm/chartjs-plugin-datalabels@2.0.0"></script>
    
    <style>
        .user-panel .info {
            display: inline-block;
            padding: 5px 5px 5px 10px;
        }
        .brand-link {
            border-bottom: none !important;
        }
        .table-responsive {
            overflow-x: auto;
        }
        .participant-photo {
            width: 40px;
            height: 40px;
            border-radius: 50%;
            object-fit: cover;
            background-color: #6c757d;
            color: white;
            display: flex;
            align-items: center;
            justify-content: center;
            font-weight: bold;
            cursor: pointer;
        }
        .participant-photo img {
            width: 100%;
            height: 100%;
            border-radius: 50%;
            object-fit: cover;
        }
        .modal-img-container {
            max-height: 70vh;
            overflow: hidden;
        }
        .modal-img-container img {
            width: 100%;
            height: auto;
            object-fit: contain;
        }
        .main-sidebar {
            position: fixed;
            height: 100vh;
            overflow-y: auto;
        }
        .content-wrapper {
            margin-left: 250px;
            overflow-y: auto;
            height: 100vh;
        }
        .main-header {
            position: fixed;
            width: 100%;
            z-index: 1030;
            left: 0;
        }
        .content {
            padding-top: 70px;
            padding-bottom: 60px;
        }
        .main-footer {
            position: fixed;
            bottom: 0;
            width: 100%;
            margin-left: 250px;
            z-index: 1000;
            background: #fff;
        }
        .pagination-container {
            display: flex;
            justify-content: center;
            margin-top: 20px;
        }
        .no-photo {
            background-color: #6c757d;
            color: white;
        }
        .btn-download {
            background-color: #28a745;
            color: white;
        }
        .btn-download:hover {
            background-color: #218838;
            color: white;
        }
        .btn-csv {
            background-color: #17a2b8;
            color: white;
        }
        .btn-csv:hover {
            background-color: #138496;
            color: white;
        }
        /* Estilos para el gráfico */
        .btn-chart {
            background-color: #6f42c1;
            color: white;
        }
        .btn-chart:hover {
            background-color: #5a32a3;
            color: white;
        }
        .chart-container {
            position: relative;
            height: 500px;
            width: 100%;
        }
        .btn-download-chart {
            background-color: #6610f2;
            color: white;
        }
        .btn-download-chart:hover {
            background-color: #520dc2;
            color: white;
        }
        .dropdown-menu .dropdown-item {
            display: flex;
            align-items: center;
            gap: 8px;
        }
        .legend-container {
            max-height: 300px;
            overflow-y: auto;
            margin-top: 20px;
            padding: 10px;
            background-color: #f8f9fa;
            border-radius: 5px;
        }
        .legend-item {
            display: flex;
            align-items: center;
            margin-bottom: 5px;
            padding: 5px;
            border-radius: 3px;
        }
        .legend-color {
            width: 20px;
            height: 20px;
            margin-right: 10px;
            border: 1px solid #ddd;
            border-radius: 3px;
        }
    </style>
</head>
<body class="hold-transition sidebar-mini">
<div class="wrapper">

    <!-- Navbar -->
    <nav class="main-header navbar navbar-expand navbar-white navbar-light">
        <!-- Left navbar links -->
        <ul class="navbar-nav">
            <li class="nav-item">
                <a class="nav-link" data-widget="pushmenu" href="#" role="button"><i class="fas fa-bars"></i></a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="dashboard.php" class="nav-link">Inicio</a>
            </li>
            <li class="nav-item d-none d-sm-inline-block">
                <a href="ver_cursos.php" class="nav-link">Cursos</a>
            </li>
        </ul>

        <!-- Right navbar links -->
        <ul class="navbar-nav ml-auto">
            <li class="nav-item">
                <a class="nav-link" href="logout.php" role="button">
                    <i class="fas fa-sign-out-alt"></i> Cerrar Sesión
                </a>
            </li>
        </ul>
    </nav>
    <!-- /.navbar -->

    <!-- Main Sidebar Container -->
    <aside class="main-sidebar sidebar-dark-primary elevation-4">
        <!-- Brand Logo -->
        <a href="dashboard.php" class="brand-link">
            <span class="brand-text font-weight-light">ESIBOC Admin</span>
        </a>

        <!-- Sidebar -->
        <div class="sidebar">
            <!-- Sidebar user panel (optional) -->
            <div class="user-panel mt-3 pb-3 mb-3 d-flex">
                <div class="image">
                    <span class="img-circle elevation-2 bg-info d-flex align-items-center justify-content-center" 
                          style="width: 40px; height: 40px; font-weight: bold; font-size: 18px;">
                        <?= strtoupper(substr($_SESSION['admin_nombre'], 0, 1)) ?>
                    </span>
                </div>
                <div class="info">
                    <a href="#" class="d-block"><?= htmlspecialchars($_SESSION['admin_nombre']) ?></a>
                </div>
            </div>

            <!-- Sidebar Menu -->
            <nav class="mt-2">
                <ul class="nav nav-pills nav-sidebar flex-column" data-widget="treeview" role="menu" data-accordion="false">
                    <li class="nav-item">
                        <a href="dashboard.php" class="nav-link">
                            <i class="nav-icon fas fa-tachometer-alt"></i>
                            <p>Dashboard</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="crear_curso.php" class="nav-link">
                            <i class="nav-icon fas fa-plus-circle"></i>
                            <p>Crear Curso</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="ver_cursos.php" class="nav-link active">
                            <i class="nav-icon fas fa-book"></i>
                            <p>Gestionar Cursos</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="inscribir_participante.php" class="nav-link">
                            <i class="nav-icon fas fa-user-plus"></i>
                            <p>Inscribir Participante</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="ver_inscritos.php" class="nav-link">
                            <i class="nav-icon fas fa-clipboard-list"></i>
                            <p>Ver Inscripciones</p>
                        </a>
                    </li>
                    <li class="nav-item">
                        <a href="logout.php" class="nav-link text-danger">
                            <i class="nav-icon fas fa-sign-out-alt"></i>
                            <p>Cerrar Sesión</p>
                        </a>
                    </li>
                </ul>
            </nav>
            <!-- /.sidebar-menu -->
        </div>
        <!-- /.sidebar -->
    </aside>

    <!-- Content Wrapper. Contains page content -->
    <div class="content-wrapper">
        <!-- Content Header (Page header) -->
        <div class="content-header">
            <div class="container-fluid">
                <div class="row mb-2">
                    <div class="col-sm-6">
                        <h1 class="m-0">Participantes del Curso</h1>
                    </div>
                    <div class="col-sm-6">
                        <ol class="breadcrumb float-sm-right">
                            <li class="breadcrumb-item"><a href="dashboard.php">Inicio</a></li>
                            <li class="breadcrumb-item"><a href="ver_cursos.php">Cursos</a></li>
                            <li class="breadcrumb-item active">Participantes</li>
                        </ol>
                    </div>
                </div>
            </div>
        </div>

        <!-- Main content -->
        <section class="content">
            <div class="container-fluid">
                <div class="row">
                    <div class="col-12">
                        <div class="card">
                            <div class="card-header">
                                <h3 class="card-title">Curso: <?= htmlspecialchars($curso['nombre']) ?></h3>
                                <div class="card-tools">
                                    <a href="ver_cursos.php" class="btn btn-sm btn-secondary">
                                        <i class="fas fa-arrow-left"></i> Volver a Cursos
                                    </a>
                                    <a href="inscribir_participante.php?curso_id=<?= $curso_id ?>" class="btn btn-sm btn-primary">
                                        <i class="fas fa-user-plus"></i> Inscribir Participante
                                    </a>
                                    <div class="btn-group ml-2">
                                        <a href="?curso_id=<?= $curso_id ?>&descargar_excel=1" class="btn btn-sm btn-success">
                                            <i class="fas fa-file-archive"></i> Descargar ZIP
                                        </a>
                                        <a href="?curso_id=<?= $curso_id ?>&descargar_excel=1&formato=csv" class="btn btn-sm btn-csv">
                                            <i class="fas fa-file-csv"></i> Descargar CSV
                                        </a>
                                        <a href="?curso_id=<?= $curso_id ?>&descargar_matricula=1" class="btn btn-sm btn-info ml-2">
    <i class="fas fa-user-graduate"></i> Descargar Matrícula
</a>
                                        
                                        <button class="btn btn-sm btn-chart show-chart-btn" data-curso-id="<?= $curso_id ?>">
                                            <i class="fas fa-chart-pie"></i> Ver Gráfico
                                        </button>
                                        <div class="btn-group">
                                            <button type="button" class="btn btn-sm btn-download-chart dropdown-toggle" data-toggle="dropdown">
                                                <i class="fas fa-download"></i> Descargar Gráfico
                                            </button>
                                            <div class="dropdown-menu">
                                                <a class="dropdown-item" href="?curso_id=<?= $curso_id ?>&descargar_grafico=html">
                                                    <i class="fas fa-file-code"></i> Como HTML
                                                </a>
                                                <a class="dropdown-item" href="?curso_id=<?= $curso_id ?>&descargar_grafico=png">
                                                    <i class="fas fa-image"></i> Como Imagen (PNG)
                                                </a>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <!-- /.card-header -->
                            <div class="card-body">
                                <?php if (isset($_SESSION['flash_message'])): ?>
                                    <div class="alert alert-<?= $_SESSION['flash_message']['type'] ?>">
                                        <?= $_SESSION['flash_message']['message'] ?>
                                    </div>
                                    <?php unset($_SESSION['flash_message']); ?>
                                <?php endif; ?>
                                <?php if (empty($participantes)): ?>
                                    <div class="alert alert-info">No hay participantes inscritos en este curso.</div>
                                <?php else: ?>
                                    <div class="table-responsive">
                                        <table id="participantesTable" class="table table-bordered table-striped">
                                            <thead>
                                                <tr>
                                                    <th>Foto</th>
                                                    <th>Nombre Completo</th>
                                                    <th>Cédula</th>
                                                    <th>Celular</th>
                                                    <th>Correo</th>
                                                    <th>Dirección</th>
                                                    <th>Departamento</th>
                                                    <th>Institución</th>
                                                    <th>Fecha Inscripción</th>
                                                    <th>Acciones</th>
                                                </tr>
                                            </thead>
                                            <tbody>
                                                <?php foreach ($participantes as $p): 
                                                    $foto_path = getFotoParticipante($p, $curso['nombre'], $curso['numero_registro']);
                                                    $iniciales = strtoupper(substr($p['nombres'], 0, 1) . substr($p['apellidos'], 0, 1));
                                                ?>
                                                    <tr>
                                                        <td>
                                                            <?php if ($foto_path && file_exists($foto_path)): ?>
                                                                <div class="participant-photo" data-foto="<?= htmlspecialchars($foto_path) ?>">
                                                                    <img src="<?= htmlspecialchars($foto_path) ?>" 
                                                                         alt="Foto de <?= htmlspecialchars($p['nombres'] . ' ' . $p['apellidos']) ?>"
                                                                         onerror="this.parentNode.innerHTML='<div class=\'participant-photo no-photo\'><?= $iniciales ?></div>'">
                                                                </div>
                                                            <?php else: ?>
                                                                <div class="participant-photo no-photo" title="Foto no disponible">
                                                                    <?= $iniciales ?>
                                                                </div>
                                                            <?php endif; ?>
                                                        </td>
                                                        <td><?= htmlspecialchars(mb_strtoupper($p['nombres'] . ' ' . $p['apellidos'])) ?></td>
                                                        <td><?= htmlspecialchars($p['cedula']) ?></td>
                                                        <td><?= htmlspecialchars($p['celular']) ?></td>
                                                        <td><?= htmlspecialchars(strtolower($p['correo'])) ?></td>
                                                        <td><?= htmlspecialchars($p['direccion'] ?? 'No especificada') ?></td>
                                                        <td><?= htmlspecialchars($p['departamento']) ?></td>
                                                        <td><?= 'CB ' . htmlspecialchars(mb_strtoupper($p['clase_cuerpo_bomberos'])) . ' ' . htmlspecialchars(mb_strtoupper($p['municipio'])) ?></td>
                                                        <td><?= date('d/m/Y', strtotime($p['fecha_inscripcion'])) ?></td>
                                                        <td>
                                                            <a href="editar_participante.php?id=<?= $p['id'] ?>" class="btn btn-sm btn-info" title="Editar">
                                                                <i class="fas fa-edit"></i>
                                                            </a>
                                                            <a href="eliminar_inscripcion.php?participante_id=<?= $p['id'] ?>&curso_id=<?= $curso_id ?>" 
                                                               class="btn btn-sm btn-danger" title="Eliminar inscripción"
                                                               onclick="return confirm('¿Está seguro de eliminar esta inscripción?');">
                                                                <i class="fas fa-trash-alt"></i>
                                                            </a>
                                                        </td>
                                                    </tr>
                                                <?php endforeach; ?>
                                            </tbody>
                                        </table>
                                    </div>
                                <?php endif; ?>
                            </div>
                            <!-- /.card-body -->
                        </div>
                        <!-- /.card -->
                    </div>
                    <!-- /.col -->
                </div>
                <!-- /.row -->
            </div><!-- /.container-fluid -->
        </section>
        <!-- /.content -->
    </div>
    <!-- /.content-wrapper -->

    <!-- Main Footer -->
    <footer class="main-footer">
        <strong>Copyright &copy; <?= date('Y') ?> <a href="#">ESIBOC</a>.</strong>
        Todos los derechos reservados.
        <div class="float-right d-none d-sm-inline-block">
            <b>Versión</b> 1.0.0
        </div>
    </footer>
</div>
<!-- ./wrapper -->

<!-- Modal para ver foto -->
<div class="modal fade" id="fotoModal" tabindex="-1" role="dialog" aria-hidden="true">
    <div class="modal-dialog modal-dialog-centered" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Foto del participante</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body text-center">
                <div class="modal-img-container">
                    <img id="fotoParticipante" src="" class="img-fluid" alt="Foto del participante">
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">Cerrar</button>
            </div>
        </div>
    </div>
</div>

<!-- Modal para el gráfico -->
<div class="modal fade" id="chartModal" tabindex="-1" role="dialog" aria-hidden="true">
    <div class="modal-dialog modal-lg" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Participación por Municipio (Cuerpo de Bomberos)</h5>
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
            </div>
            <div class="modal-body">
                <div class="chart-container">
                    <canvas id="participationChart"></canvas>
                </div>
                <div class="legend-container">
                    <h5>Leyenda Detallada</h5>
                    <div id="customLegend" class="d-flex flex-wrap"></div>
                </div>
                <div id="chartTableContainer" class="mt-4"></div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-dismiss="modal">Cerrar</button>
                <a href="?curso_id=<?= $curso_id ?>&descargar_grafico=html" class="btn btn-download-chart">
                    <i class="fas fa-file-code"></i> Descargar HTML
                </a>
                <button class="btn btn-download-chart download-chart-as-image">
                    <i class="fas fa-image"></i> Descargar PNG
                </button>
            </div>
        </div>
    </div>
</div>

<!-- REQUIRED SCRIPTS -->
<!-- jQuery -->
<script src="https://cdn.jsdelivr.net/npm/jquery@3.6.0/dist/jquery.min.js"></script>
<!-- Bootstrap 4 -->
<script src="https://cdn.jsdelivr.net/npm/bootstrap@4.6.0/dist/js/bootstrap.bundle.min.js"></script>
<!-- AdminLTE App -->
<script src="https://cdn.jsdelivr.net/npm/admin-lte@3.2/dist/js/adminlte.min.js"></script>
<!-- DataTables -->
<script src="https://cdn.datatables.net/1.11.5/js/jquery.dataTables.min.js"></script>
<script src="https://cdn.datatables.net/1.11.5/js/dataTables.bootstrap4.min.js"></script>

<script>
    $(function () {
        // Inicializar DataTable
        $('#participantesTable').DataTable({
            "responsive": true,
            "autoWidth": false,
            "language": {
                "lengthMenu": "Mostrar _MENU_ registros por página",
                "zeroRecords": "No se encontraron resultados",
                "info": "Mostrando página _PAGE_ de _PAGES_",
                "infoEmpty": "No hay registros disponibles",
                "infoFiltered": "(filtrado de _MAX_ registros totales)",
                "search": "Buscar:",
                "paginate": {
                    "first": "Primero",
                    "last": "Último",
                    "next": "Siguiente",
                    "previous": "Anterior"
                }
            }
        });

        // Mostrar foto en modal al hacer clic
        $(document).on('click', '.participant-photo', function() {
            var fotoSrc = $(this).data('foto') || $(this).find('img').attr('src');
            if (fotoSrc) {
                $('#fotoParticipante').attr('src', fotoSrc);
                $('#fotoModal').modal('show');
            }
        });
    });

    // Script para el gráfico con porcentajes visibles
    $(document).on('click', '.show-chart-btn', function() {
        var cursoId = $(this).data('curso-id');
        
        // Mostrar loading
        $('#chartModal .modal-body').html(`
            <div class="text-center py-5">
                <i class="fas fa-spinner fa-spin fa-3x"></i>
                <p>Cargando datos...</p>
            </div>
        `);
        $('#chartModal').modal('show');
        
        // Datos del gráfico desde PHP
        var chartData = {
            municipios: <?= json_encode($municipios) ?>,
            conteos: <?= json_encode($conteos) ?>,
            porcentajes: <?= json_encode($porcentajes) ?>,
            colores: <?= json_encode($colores) ?>,
            total: <?= $totalParticipantes ?>
        };
        
        renderChart(chartData);
    });

    function renderChart(data) {
        // Verificar datos
        if (!data.municipios || data.municipios.length === 0) {
            $('#chartModal .modal-body').html(`
                <div class="alert alert-warning">
                    No hay suficientes datos para mostrar el gráfico.
                </div>
            `);
            return;
        }

        // Crear HTML para el gráfico
        var html = `
            <div class="chart-container">
                <canvas id="participationChart"></canvas>
            </div>
            <div class="legend-container">
                <h5>Leyenda Detallada</h5>
                <div id="customLegend" class="d-flex flex-wrap"></div>
            </div>
            <div id="chartTableContainer" class="mt-4">
                <h5>Detalle de Participación</h5>
                <div class="table-responsive">
                    <table class="table table-bordered table-striped">
                        <thead>
                            <tr>
                                <th>Municipio</th>
                                <th>Participantes</th>
                                <th>Porcentaje</th>
                            </tr>
                        </thead>
                        <tbody>
        `;

        // Generar filas de la tabla
        for (var i = 0; i < data.municipios.length; i++) {
            html += `
                <tr>
                    <td>${data.municipios[i]}</td>
                    <td>${data.conteos[i]}</td>
                    <td>${data.porcentajes[i]}%</td>
                </tr>
            `;
        }

        html += `
                        </tbody>
                        <tfoot>
                            <tr>
                                <th>Total</th>
                                <th>${data.total}</th>
                                <th>100%</th>
                            </tr>
                        </tfoot>
                    </table>
                </div>
            </div>
        `;

        $('#chartModal .modal-body').html(html);

        // Configuración del gráfico con porcentajes visibles
        var ctx = document.getElementById('participationChart').getContext('2d');
        var chart = new Chart(ctx, {
            type: 'pie',
            data: {
                labels: data.municipios,
                datasets: [{
                    data: data.conteos,
                    backgroundColor: data.colores,
                    borderWidth: 1
                }]
            },
            options: {
                responsive: true,
                maintainAspectRatio: false,
                plugins: {
                    legend: {
                        display: false, // Ocultamos la leyenda estándar
                    },
                    tooltip: {
                        callbacks: {
                            label: function(context) {
                                return `${context.label}: ${context.raw} (${data.porcentajes[context.dataIndex]}%)`;
                            }
                        }
                    },
                    datalabels: {
                        display: true,
                        color: function(context) {
                            // Color blanco para mejor contraste
                            return '#ffffff';
                        },
                        font: {
                            weight: 'bold',
                            size: 12
                        },
                        formatter: function(value, ctx) {
    return data.municipios[ctx.dataIndex] + ': ' + data.porcentajes[ctx.dataIndex] + '%';
                        },
                        anchor: 'center',
                        align: 'center',
                        offset: 0,
                        padding: 0,
                        clip: false,
                        textShadowBlur: 10,
                        textShadowColor: 'black'
                    }
                },
                layout: {
                    padding: {
                        top: 20,
                        bottom: 20,
                        left: 20,
                        right: 20
                    }
                },
                elements: {
                    arc: {
                        borderWidth: 0
                    }
                }
            },
            plugins: [ChartDataLabels]
        });

        // Crear leyenda personalizada
        var legendHtml = '';
        for (var i = 0; i < data.municipios.length; i++) {
            legendHtml += `
                <div class="legend-item mr-4 mb-2">
                    <span class="legend-color" style="background-color:${data.colores[i]};"></span>
                    <span>${data.municipios[i]} (${data.conteos[i]} - ${data.porcentajes[i]}%)</span>
                </div>
            `;
        }
        $('#customLegend').html(legendHtml);

        // Configurar botón de descarga
        $('.download-chart-as-image').click(function() {
            var link = document.createElement('a');
            link.download = 'grafico_participacion_<?= $curso_id ?>.png';
            link.href = document.getElementById('participationChart').toDataURL('image/png');
            document.body.appendChild(link);
            link.click();
            document.body.removeChild(link);
        });
    }
</script>

</body>
</html>
<?php
// Finalizar buffer de salida
ob_end_flush();
?>